.storytelling-hero {
    position: relative;

    &:before {
        content: "";
        background: #000;
        position: absolute;
        bottom: 50%;
        width: 200vw;
        height: 150vh;
        z-index: -1;
        left: -50vw;
    }

    .hero-texture {
        display: none;
        position: absolute;
        top: 0;
        width: 100%;
        padding: 2rem 0rem;

        img {
            height: 100%;
            object-fit: cover;
        }
    }

    .hero-image-wrapper {
        &::before {
            content: '';
            display: inline-block;
            background-image: url('./../../../images/Student-storytelling-texture-background.png');
            background-size: cover;
            background-repeat: no-repeat;
            background-position: center;
            position: absolute;
            top: 0;
            max-height: 75%;
            width: 100%;
            height: 100%;
            align-self: center;
            bottom: 0;
            border-radius: 4px;
        }

        z-index: 1;
    }

    .hero-image {
        max-width: 75%;
        margin-left: 25%;
        z-index: 1;
        position: relative;

        @include mobile {
            object-fit: cover;
            object-position: center;
            height: 100%;
            width: 100%;
            max-width: 50%;
            margin-left: 50%;
            border-radius: 4px;

            &.image-position-left {
                object-position: left;
            }
            &.image-position-right {
                object-position: right;
            }
        }
    }

    .hero-image-container {
        @include mobile {
            width: 100%;
            height: 400px;
            overflow: hidden;
            display: flex;
            align-items: center;
            justify-content: center;
            border-radius: 4px;
        }
    }

    h1.hero-title-wrapper {
        z-index: 2;
        position: absolute;
        top: 0;
        bottom: 0;
        left: 4rem;
        display: block;
        margin: auto 0;
        height: fit-content;

        @include mobile {
            left: auto;
            padding: 0 1.25rem;
        }

        .hero-title {
            color: #000;
            font-family: $source-serif-pro;
            font-size: 2.5rem;
            display: block;
            padding-bottom: 1rem;
            font-style: italic;
        }

        .hero-subtitle {
            font-family: $united-sans-condensed;
            font-weight: 500;
            color: #ffffff;
            text-transform: uppercase;
            background-color: #000;
            box-decoration-break: clone;
            -webkit-box-decoration-break: clone;
            padding: .25em .2em .1em;
            line-height: 1.5;
            margin-top: .5rem;
            border-radius: 4px;
        }
    }

}