.rkv-default-archive-card-slider__wrapper[class] {
	padding: 0;
	position: relative;

	.rkv-default-archive-card-slider {
		.rkv-default-archive-card-slider-slides {
			// @include archive-card;
		}
	}

	@include purdue_carousel_tinyslider_default(100%);

	// Editor

	.editor-styles-wrapper .is-root-container[class] & {
		width: 100%;
		.rkv-default-archive-card-slider {
			width: 100%;
			.rkv-default-archive-card-slider-slides {
				min-width: 100%;
				display: flex;
				flex-wrap: nowrap;
				overflow-x: scroll;
				overflow-y: hidden;
				flex-direction: row;
				padding-bottom: 16px;
				margin-bottom: 16px;
				padding-left: 0;
				gap: 10px;
				> .rkv-default-archive-card-slider-slides__slide {
					min-width: 320px;
					min-height: 400px;
				}
				&::-webkit-scrollbar {
					height: 2px;
				}
				&::-webkit-scrollbar-track {
					background-color: $-purdue-black;
					border-radius: 0;
					opacity: 0.25;
				}
				&::-webkit-scrollbar-thumb {
					border-radius: 0;
					background-color: $-purdue-black;
					height: 5px;
				}
				.archive-card {
					margin-right: 25px;
					position: relative;
					box-sizing: border-box;
					flex-shrink: 0;
					a {
						pointer-events: none;
					}
				}
			}
		}
	}
}
