/*
NOTE:

Use this file to add overrides.

First, check if there a variable you could use instead.

https://github.com/reaktivstudios/rkv-component-library/blob/master/src/styles/components/_rkv-block-quote.scss

UI example here:

https://ui.reaktivstudios.com/storybook/?path=/story/blockquote--example
*/

.wp-block-quote[class], .rkv-block-quote {
	background: $-purdue-black;
	color: $-purdue-white;
	border: none;
	padding: 6.5rem 6rem 5rem 215px;
	position: relative;
	margin-bottom: 3rem;
	margin-top:3rem;
	border-radius:4px;
	@include touch{
		margin-bottom: 2rem;
		margin-top:3rem;
	}
	@include mobile {
		padding:10rem 2.5rem 4rem 2.5rem;
	}
	&:before {
		content: '';
		background-image: url("data:image/svg+xml,%3Csvg width='105' height='96' viewBox='0 0 105 96' fill='none' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath d='M99.5 32.25H79.75V19.25L81 18H96.75V1.5H69.75L55.25 16V73.75H89.5M2 73.75V16L16.5 1.5H43.5V18H27.75L26.5 19.25V32.25H43.5V73.75H2Z' stroke='%23CFB991' stroke-width='3'/%3E%3Cline x1='84.1639' y1='95.5252' x2='103.067' y2='17.7905' stroke='white' stroke-width='2.75'/%3E%3C/svg%3E%0A");
		display: block;
		width:150px;
		height: 100px;
		background-repeat: no-repeat;
		position: absolute;
		left: 100px;
		top: 80px;
		@include mobile {
			top: 3rem;
			left: 1.5rem;
		}
	  }
	p {
		text-align: left;
		font-weight: 700;
		font-size: 1.75rem;
		font-family: $acumin-pro;
		line-height: 1.21;
		position: relative;
		z-index: 2;
		&:first-child:before {
			content: none;
		}

	}
	cite {
		text-align: left;
		font-size: 1rem;
		font-weight: 700;
		line-height: 1.5;
		font-family: $acumin-pro-condensed;
		letter-spacing: 1.6px;
		text-transform: uppercase;
		em {
			font-style: unset;
			text-transform: none;
			font-weight: 400;
			font-family: $acumin-pro;
		}
	}
}
