.purdue-at-a-glance{
    background-color: #f8f8f8;

    ul:last-child, li:last-child{
        padding-bottom: 0;
    }

    &__expand{
        font-weight: bold;
        border: none;
        font-size: 1rem;
        background: transparent;
        cursor: pointer;
        &:after {
            content: "";
            height: 3px;
            width: 100%;
            position: relative;
            display: block;
            bottom: 0;
            left: 0;
            visibility: hidden;
            background: #8e6f3e;
            transform: scaleX(0);
            transition: all .25s cubic-bezier(1, 0.25, 0, 0.75) 0s;
          }

          &:hover {
            &:after {
              visibility: visible;
              transform: scaleX(1);
            }
          }
          
    }
    
    .details-text{
        opacity: 0;
        display: none;
        transition: all .3s;
        animation: fadeIn 1s;
        height: 0;
        position: relative;
        overflow: hidden;
    }

    &.is-open{
        .details-text{
            opacity: 1;
            display: inline;
            height: auto;
            transition: opacity 1.5s ease-in-out;
        }
    }

    .purdue-at-a-glance__wrapper,.details-text{
       p{
        padding-left: 2.5rem;
        &:last-child{
            margin-bottom: 1.875rem;
        }
       } 
       li:first-child{
        padding-top: 1rem;
       }
    }
}