.photo-essay .is-12-desktop{text-align:center}.photo-essay .is-12-desktop figure>figcaption,.photo-essay .is-12-desktop .wp-block-image>figcaption{text-align:center;margin:1.5rem auto 0 auto !important;border:none}.photo-essay .is-fullheight .wp-block-image img{height:100% !important}
