.rkv-block-purdue-callout {
	font-size: 1em;
	line-height: 1;
	position: relative;
	max-width: 1112px;
	margin-left: 0;
	margin-right: -556px;
	@media (max-width: 89.99em) {
		max-width: 100vw;
		margin-left: 0;
		margin-right: calc(-1 * (100vw - 100%) / 2);
		padding-right: 16px;
	}
	&:after {
		content: none;
	}
	> p {
		font-size: 1em;
		text-align: left;
		line-height: 1.5;
	}
}

.rkv-block-purdue-callout {
	.no-image {
		.callout__text {
			margin-top: 0 !important;
		}
	}

	.callout-wrapper {
		margin-left: 35px !important;
		margin-bottom: 10px !important;
		width: 318px;
		float: right;
		margin: 0;
		display: block;
		position: relative;

		figure {
			margin: 0;
		}

		.callout__text {
			margin-top: 25px;
			display: block;
			width: 318px;
			position: relative;
			text-align: left;
			font-family: $acumin-pro;
			font-size: 0.875rem;
			letter-spacing: 0px;
			color: #555960;
			line-height: 1.5;
			font-style: italic;
		}

		.read-more-button {
			border-radius: 0 !important;
			font-family: $acumin-pro !important;
			font-weight: 400 !important;
			font-size: 1rem !important;
			padding: 0.75rem 1.5rem !important;
			background-color: $-purdue-yellow !important;
			color: black !important;
			border: 2px solid #000 !important;
			height: auto;
			margin-top: 1rem;
			&:hover {
				text-decoration: none !important;
				color: $-purdue-yellow !important;
				background-color: black !important;
				border: 2px solid #000 !important;
			}
		}

		&:before {
			content: '';
			border-left: 2px solid #cfb991;
			position: absolute;
			height: 100%;
			top: 0;
			left: -20px;
		}
	}

	@include mobile {
		.callout-wrapper {
			width: 100%;
			margin-left: 0 !important;
			padding-left: 20px;
			margin-bottom: 32px !important;
			&:before {
				left: 0;
			}

			.callout__text {
				width: 100%;
			}
		}

		.no-image {
			margin-bottom: 64px !important;
			.callout__text {
				width: 100%;
			}
		}
	}
}
