.purdue-at-a-glance{background-color:#f8f8f8}.purdue-at-a-glance ul:last-child,.purdue-at-a-glance li:last-child{padding-bottom:0}.purdue-at-a-glance__expand{font-weight:bold;border:none;font-size:1rem;background:rgba(0,0,0,0);cursor:pointer}.purdue-at-a-glance__expand:after{content:"";height:3px;width:100%;position:relative;display:block;bottom:0;left:0;visibility:hidden;background:#8e6f3e;transform:scaleX(0);transition:all .25s cubic-bezier(1, 0.25, 0, 0.75) 0s}.purdue-at-a-glance__expand:hover:after{visibility:visible;transform:scaleX(1)}.purdue-at-a-glance .details-text{opacity:0;display:none;transition:all .3s;animation:fadeIn 1s;height:0;position:relative;overflow:hidden}.purdue-at-a-glance.is-open .details-text{opacity:1;display:inline;height:auto;transition:opacity 1.5s ease-in-out}.purdue-at-a-glance .purdue-at-a-glance__wrapper p,.purdue-at-a-glance .details-text p{padding-left:2.5rem}.purdue-at-a-glance .purdue-at-a-glance__wrapper p:last-child,.purdue-at-a-glance .details-text p:last-child{margin-bottom:1.875rem}.purdue-at-a-glance .purdue-at-a-glance__wrapper li:first-child,.purdue-at-a-glance .details-text li:first-child{padding-top:1rem}
