.search-result-container{
  padding-top:2rem;
  .navigation.pagination{
    width:100%;
  }
}
.search-sort-form{
  .search-sort-field{
    display: flex;
    padding: 0.75rem 1.5rem;
    justify-content: space-around;
    align-items: center;
    border: 0.5px solid $steam-gray;
    background: $white;
    margin-left: 1rem;
    border-radius: 4px;
    margin-bottom:0;
    @include mobile{
      margin-left:0;
    }
    .sort-label{
      font-family: $united-sans-condensed;
      font-size: 1.25rem;
      font-style: normal;
      font-weight: 700;
      line-height: normal;
      letter-spacing: .075rem;
      text-transform: uppercase;
    }
    label{
      display: block;
      position: relative;
      padding-left: 1.8rem;
      cursor: pointer;
      font-size: 1rem;
      user-select: none;
      margin-left:1rem;
      input{
        position: absolute;
        opacity: 0;
        cursor: pointer;
        height: 0;
        width: 0;
        &:checked~.checkmark:after {
          display: block;
      }
      }
      .checkmark{
        position: absolute;
        top: 4px;
        left: 0;
        height: 1rem;
        width: 1rem;
        background-color: #fff;
        border: 1px solid #000;
        border-radius: 50%;
        &:after{
          content: "";
          position: absolute;
          border-radius: 50%;
          display:none;
          background: $aged-gold;
          width: 10px;
          height: 10px;
          left: calc(50% - 5px);
           top: calc(50% - 5px);
        }

      }
    }
  }
}
.search-results-header{
  align-items: center;
  @include mobile{
    flex-direction: column;
    align-items: flex-start;
  }
}