.photo-essay{    
    .is-12-desktop{
        text-align: center;
        figure>figcaption, .wp-block-image>figcaption{
            text-align: center;
            margin: 1.5rem auto 0 auto !important;
            border: none;
        }
    }

    .is-fullheight{
        .wp-block-image{
             img{
                height: calc(100%) !important;
            }
        }
       
    }
}
