/* -- Color Defaults -- */

// Colors
$black:	hsl(0, 0%, 0%);
$white:	hsl(0, 0%, 100%);
$boiler-gold:#CFB991;
$aged-gold:#8e6f3e;
$rush-gold:#daaa00;
$field-gold:#ddb945;
$dust-gold:#ebd99f;
$steel-gray:#555960;
$cool-gray:#6f727b;
$steam-gray:#c4bfc0;
$railway-gray:#9d9795;
$opaque:rgba(0,0,0,0.65);
$transparent: rgba(0,0,0,0);
$gray-footer:#2e2e2e;
$black-ter:$steel-gray;
$grey-lighter:#ededed;
$grey-secondary:#f7f7f7;

// Color Elements
$link: $aged-gold;
$success: $aged-gold;
$warning: $rush-gold;
$danger: $rush-gold;

.has-white-color{
    color:$white !important;
}
.has-black-color{
    color:$black !important;
}
.has-aged-gold-color{
    color:$aged-gold !important;
}
.has-boiler-gold-color{
    color:$boiler-gold !important;
}
.has-rush-gold-color{
    color:$rush-gold !important;
}
.has-field-gold-color{
    color:$field-gold !important;
}
.has-dust-gold-color{
    color:$dust-gold !important;
}
.has-steel-gray-color{
    color:$steel-gray !important;
}
.has-cool-gray-color{
    color:$cool-gray !important;
}
.has-steam-gray-color{
    color:$steam-gray !important;
}
.has-railway-gray-color{
    color:$railway-gray !important;
}
.has-opaque-color{
    color:$opaque !important;
}
.has-transparent-color{
    color:$transparent !important;
}

.has-white-background-color{
    background-color:$white !important;
}
.has-black-background-color{
    background-color:$black !important;
}
.has-aged-gold-background-color{
    background-color:$aged-gold !important;
}
.has-boiler-gold-background-color{
    background-color:$boiler-gold !important;
}
.has-rush-gold-background-color{
    background-color:$rush-gold !important;
}
.has-field-gold-background-color{
    background-color:$field-gold !important;
}
.has-dust-gold-background-color{
    background-color:$dust-gold !important;
}
.has-steel-gray-background-color{
    background-color:$steel-gray !important;
}
.has-cool-gray-background-color{
    background-color:$cool-gray !important;
}
.has-steam-gray-background-color{
    background-color:$steam-gray !important;
}
.has-railway-gray-background-color{
    background-color:$railway-gray !important;
}
.has-opaque-background-color{
    background-color:$opaque !important;
}
.has-transparent-background-color{
    background-color:$transparent !important;
}
.has-background-black-ter{
    background-color:$steel-gray !important;
}

$-purdue-yellow: #cfb991;
$-purdue-boiler-gold: $-purdue-yellow;
$-purdue-black: #000000;
$-purdue-yellow-brighter: #daaa00;
$-purdue-aged: #8e6f3e;
$-purdue-aged-digital-gold: $-purdue-aged;
$-purdue-yellow-darker: $-purdue-aged;
$-purdue-white: #fff;
$-purdue-steel: #555960;
$-purdue-digital-gray: #ededed;
$-purdue-gray: #6f727b;
$-purdue-grey: $-purdue-gray;
$primary-background-gray: #ededed;
$-rkv-color-black: #000;
$-rkv-color-black-alpha-50: rgba($-rkv-color-black, 0.5);
$-rkv-color-black-alpha-75: rgba($-rkv-color-black, 0.75);