@import "../front-end/variables.scss";
@import "../../../node_modules/bulma/bulma.sass";
@import "../front-end/rkv-block-quote";
@import "../front-end/rkv-block-pull-quote";

@import '../front-end//posts_slider_variation_4';
.post-select{
    .media-modal-backdrop{
        z-index:0;
    }
    .modal{
        display: block !important;
    }
}