// ====================
// Default placeholder.
// ====================

/*
	This is empty by default, but the intent
	is that it would be overwritten by another
	variable for a custom site implementation.
*/

// prettier-ignore
$-rkv-custom-feature-map: (
	// Leave this blank!
) !default;

// ===============================
// Features. Private to this file.
// ===============================

// prettier-ignore
$-rkv-default-feature-map: (
	charts: true,
	gravity-forms: true,
	grid: true,
	layout: true,
	masonry: true,
	syntax: true,
	table-of-contents: true,
	wordpress: true,
) !default;

// ===================
// Merge feature maps.
// ===================

// prettier-ignore
$-rkv-merged-feature-map: rkv-map-merge(
	$-rkv-default-feature-map,
	$-rkv-custom-feature-map
) !default;
