.wp-block-gallery.has-nested-images figure.wp-block-image:has(figcaption):before {
    content: none !important;
}

.wp-block-gallery.has-nested-images figure.wp-block-image figcaption {
    text-shadow: none;
}