/**
 * #.# Editor Styles
 *
 * CSS for just Backend enqueued after style.scss
 * which makes it higher in priority.
 */


.wp-block-purdue-storytelling-side-by-side {
  display: block;
  color: #000;
  margin: 1rem auto;

  .block-editor-inner-blocks {
    display: flex;
    width: 100%;
    .block-editor-block-list__layout {
      display: flex;
      flex-grow: 1;
      &:not(.is-desktop) {
        display: flex !important;
        flex-wrap: wrap;
      }

      margin-bottom: -0.75rem;
      margin-top: -0.75rem;
    }

    .bulma-blocks-editor-column{
      display: flex;
      justify-content: center;
    }
  }
}