.has-white-color{color:#fff !important}.has-black-color{color:#000 !important}.has-aged-gold-color{color:#8e6f3e !important}.has-boiler-gold-color{color:#cfb991 !important}.has-rush-gold-color{color:#daaa00 !important}.has-field-gold-color{color:#ddb945 !important}.has-dust-gold-color{color:#ebd99f !important}.has-steel-gray-color{color:#555960 !important}.has-cool-gray-color{color:#6f727b !important}.has-steam-gray-color{color:#c4bfc0 !important}.has-railway-gray-color{color:#9d9795 !important}.has-opaque-color{color:rgba(0,0,0,.65) !important}.has-transparent-color{color:rgba(0,0,0,0) !important}.has-white-background-color{background-color:#fff !important}.has-black-background-color{background-color:#000 !important}.has-aged-gold-background-color{background-color:#8e6f3e !important}.has-boiler-gold-background-color{background-color:#cfb991 !important}.has-rush-gold-background-color{background-color:#daaa00 !important}.has-field-gold-background-color{background-color:#ddb945 !important}.has-dust-gold-background-color{background-color:#ebd99f !important}.has-steel-gray-background-color{background-color:#555960 !important}.has-cool-gray-background-color{background-color:#6f727b !important}.has-steam-gray-background-color{background-color:#c4bfc0 !important}.has-railway-gray-background-color{background-color:#9d9795 !important}.has-opaque-background-color{background-color:rgba(0,0,0,.65) !important}.has-transparent-background-color{background-color:rgba(0,0,0,0) !important}.has-background-black-ter{background-color:#555960 !important}.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}hr.wp-block-separator{height:1px !important}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.united-sans-font{font-family:"United Sans",Impact,"Arial Black","sans serif" !important}strong{color:inherit !important}.storytelling-qa-block{text-align:center;font-size:1.25rem;border-radius:4px;padding-top:0 !important}.storytelling-qa-block .storytelling-qa-block__qa{margin-bottom:2rem}.storytelling-qa-block .storytelling-qa-block__qa p{font-family:"United Sans Condensed",Impact,"Arial Black","sans serif";font-weight:500;font-size:3rem;text-transform:uppercase;margin-bottom:1rem;color:#000;background-color:#cfb991;display:inline-flex;padding:1rem;line-height:1}.storytelling-qa-block p.qa-question{font-family:"United Sans",Impact,"Arial Black","sans serif";font-weight:700;font-size:1.25rem;line-height:1.25;text-transform:uppercase;margin-bottom:.25rem;color:#cfb991}.storytelling-qa-block.has-background-black p.qa-answer{color:#fff}.storytelling-qa-block.has-background-grey-lighter .storytelling-qa-block__qa p{color:#cfb991;background-color:#000}.storytelling-qa-block.has-background-grey-lighter p.qa-question{color:#000}.storytelling-qa-block.has-background-grey-lighter-alt{background-color:#ededed}.storytelling-qa-block.has-background-grey-lighter-alt .storytelling-qa-block__qa p{color:#fff;background-color:#000}.storytelling-qa-block.has-background-grey-lighter-alt p.qa-question{color:#8e6f3e}.storytelling-qa-block.has-background-rush-gold{background-color:#daaa00}.storytelling-qa-block.has-background-rush-gold .storytelling-qa-block__qa p{color:#fff;background-color:#555960}.storytelling-qa-block.has-background-rush-gold p.qa-question{color:#000}.storytelling-qa-block.has-background-dark-gray{background-color:#555960}.storytelling-qa-block.has-background-dark-gray .storytelling-qa-block__qa p{color:#000;background-color:#fff}.storytelling-qa-block.has-background-dark-gray p.qa-question,.storytelling-qa-block.has-background-dark-gray p{color:#fff}.storytelling-qa-block.has-background-gold{background-color:#cfb991}.storytelling-qa-block.has-background-gold .storytelling-qa-block__qa p{color:#8e6f3e;background-color:#ededed}.storytelling-qa-block.has-background-gold p.qa-question{color:#000}
