/*
NOTE:

Use this file to add overrides.

First, check if there a variable you could use instead.

https://github.com/reaktivstudios/rkv-component-library/blob/master/src/styles/components/_rkv-accordion.scss

UI example here:

https://ui.reaktivstudios.com/storybook/?path=/story/accordion--default
*/

.rkv-accordion {
	border: 1px solid #ededed;
	border-radius: 4px;
	font-family: acumin-pro, 'Franklin Gothic', sans-serif;
	margin: 1rem 0;
	position: relative;
	cursor: pointer;
	background-color: #ffffff;
	box-shadow: 0 3px 6px rgb(0 0 0 / 16%);
	&:last-child {
		margin-bottom: 0;
	}
	&__title {
		padding: 1.25rem 3.25rem 1.25rem 1.25rem;
		font-size: 1.25rem;
		font-weight: 700;
		line-height: 1.5;
		color: #000 !important;
		position: relative;
		margin-bottom: 0 !important;
		&:after {
			content: ' ';
			display: block;
			background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 512 512'%3E%3C!--! Font Awesome Pro 6.2.1 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2022 Fonticons, Inc. --%3E%3Cpath fill='%238e6f3e' d='M233.4 406.6c12.5 12.5 32.8 12.5 45.3 0l192-192c12.5-12.5 12.5-32.8 0-45.3s-32.8-12.5-45.3 0L256 338.7 86.6 169.4c-12.5-12.5-32.8-12.5-45.3 0s-12.5 32.8 0 45.3l192 192z'/%3E%3C/svg%3E");
			width: 20px;
			height: 30px;
			background-size: 20px 20px;
			background-repeat: no-repeat;
			background-position: 10%;
			position: absolute;
			right: 1.25rem;
			top: 1.25rem;
		}
		@include mq($until: md) {
			font-size: 1.125rem;
		}
	}
	&__content {
		display: block;
		padding: 0 1.25rem;
		transition: all 0.3s;
		box-sizing: border-box;
		position: relative;
		width: 100%;
		z-index: 1;
		overflow: hidden;
		max-height: 0;
		opacity: 0;
		p,li{
			color: #000000 !important;
		}

	}
	&.expandChildMenu {
		background-color: #ffffff;
		.rkv-accordion__title {
			&:after {
				background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 512 512'%3E%3C!--! Font Awesome Pro 6.2.1 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2022 Fonticons, Inc. --%3E%3Cpath fill='%238e6f3e' d='M233.4 105.4c12.5-12.5 32.8-12.5 45.3 0l192 192c12.5 12.5 12.5 32.8 0 45.3s-32.8 12.5-45.3 0L256 173.3 86.6 342.6c-12.5 12.5-32.8 12.5-45.3 0s-12.5-32.8 0-45.3l192-192z'/%3E%3C/svg%3E");
			}
		}
		.rkv-accordion__content {
			max-height: 999999px;
			padding: 0.875rem 1.25rem 0;
			opacity: 1;
			color: #000000;
		}
	}
}
