.purdue-home-image-slider--has-text{
	.purdue-home-image-slider__card {
		height:100%;
		&.purdue-home-cta-card {
		  display:flex;
		  cursor:default;
		  @include mobile{
			flex-direction:column;
		  }
		  .flex-container--align-bottom{
			width:40%;
			padding:2.5rem;
			display:flex;
			flex-direction: column;
			justify-content: flex-end;
			align-items: flex-start;
			height: auto;
			position: relative;
			@include mobile{
			  width:100%;
			  padding:2.5rem 1.125rem;
			  height:100%;
			  justify-content: flex-start;
			}
		  }
		}
		
		&-image{
		  flex:1;
		  @include mobile{
			width:100%;
			flex:0;
		  }
		  .image{
			  height:100%;
			min-height:400px;
			@include mobile{
			  min-height:1px;
			}
			&:after{
			  content:none !important;
			}
			img{
				border-radius: 0;
			}
		  }
		}
		&-title{
		  font-size:1.5rem;
		  font-weight:700;
		  line-height:1.1;
		  @include until-widescreen {
			font-size:1.5rem;
		  }
		}
		&-subtext{
			font-size:1rem;
			-webkit-line-clamp: 3;
			-webkit-box-orient: vertical;
			display: -webkit-box;
			overflow: hidden;
			text-overflow: ellipsis;
		  }
		  .purdue-home-button{
			@include mobile{
				margin-top: auto;
			  }
		  }
	  }
	  .glide__slide {
		padding:0.2rem;
		height:auto;
	  }
	  .slider-controls{
		margin-top: 3rem;
		@include mobile{
			margin-top: 2rem;
		}
	  }
	  margin:3rem 0;
	  @include mobile{
		margin:2rem 0;
	  }
}
