.photo-essay-blocks-editor-columns{display:block;color:#000}.photo-essay-blocks-editor-columns>.block-editor-inner-blocks>.block-editor-block-list__layout:not(.is-desktop){display:flex;flex-wrap:wrap}.photo-essay-blocks-editor-columns>.block-editor-inner-blocks>.block-editor-block-list__layout{margin-bottom:-0.75rem;margin-top:-0.75rem}.bulma-columns-range-control{width:100%}.bulma-columns-range-control label{margin-bottom:1rem !important}.bulma-columns-range-control .components-range-control__number{margin:0 !important}.bulma-columns-range-control .components-range-control__slider{display:none}.bulma-columns-range-control .components-base-control__field{justify-content:flex-start}.block-editor-block-list__layout .block-editor-block-list__block[data-block]{margin-bottom:1rem;margin-top:1rem}.block-editor-block-list__layout .block-editor-block-list__block[data-block]::before{top:0;right:0;bottom:0;left:0}
