@use 'sass:math';
@import "./colors";
$black: #000;

$footer-background-color:$black;
$widescreen: 1407px;
$desktop: 1215 px;
$tablet: 768px;
$mobile-plus:414px;
$stickySideNav-desktop: 1322px;
$stickySideNav-tablet: 1066px;
$text: $black;

$content-heading-color: $black;

$side-padding-desktop:3.25rem;
$side-padding-tablet:1.5rem;
$side-padding-mobile:1.25rem;
$box-shadow:0 0.5em 1em -0.125em rgba(0, 0, 0, 0.1), 0 0px 0 1px rgba(0, 0, 0, 0.02);
$box-shadow-hover: 0 14px 28px rgba(0,0,0,0.25), 0 10px 10px rgba(0,0,0,0.22);

$acumin-pro-condensed: acumin-pro-condensed,
"Franklin Gothic",
sans-serif;
$acumin-pro-semicondensed: acumin-pro-semi-condensed,
"Franklin Gothic",
sans-serif;
$acumin-pro: acumin-pro,
"Franklin Gothic",
sans-serif;
$united-sans: "United Sans",
Impact,
"Arial Black",
"sans serif";
$united-sans-condensed: "United Sans Condensed",
Impact,
"Arial Black",
"sans serif";
$united-sans-extended: "United Sans Extended",
Impact,
"Arial Black",
"sans serif";

$source-serif-pro: source-serif-pro,Georgia,serif;
$family-sans-serif: acumin-pro,
"Franklin Gothic",
sans-serif;

.main-content {
    display: block;
}

.home{
    .content{
        margin-bottom: 0 !important;
    }
}
.main-content>.content:not(:last-child){
    margin-bottom: 0 !important;
}
.content p{
    max-width:100%;
}
hr.wp-block-separator {
    height: 1px !important;
}
@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none) {
	.columns.is-multiline{
		flex-wrap:none;
	}
	.column{
		flex-basis:auto;
	} 
}

.united-sans-font{
    font-family:$united-sans !important;
}
strong{
    color: inherit !important;
}


//from RKV theme
// ==================
// Internal defaults.
// ==================

$side-padding-desktop: 3.25rem;
$side-padding-tablet: 1.5rem;
$side-padding-mobile: 1rem;
$box-shadow: 0 3px 6px #00000029;
$box-shadow-hover: 0 14px 28px rgba(0, 0, 0, 0.25), 0 10px 10px rgba(0, 0, 0, 0.22);
$-rkv-border-radius-default: 5px;

$acumin-pro-condensed: acumin-pro-condensed, 'Franklin Gothic', sans-serif;
$acumin-pro-semicondensed: acumin-pro-semi-condensed, 'Franklin Gothic', sans-serif;
$acumin-pro: acumin-pro, 'Franklin Gothic', sans-serif;
$united-sans: 'United Sans', Impact, 'Arial Black', 'sans serif';
$united-sans-condensed: 'United Sans Condensed', Impact, 'Arial Black', 'sans serif';
$united-sans-extended: 'United Sans Extended', Impact, 'Arial Black', 'sans serif';


// $rkv-font-family-caps: 'Nunito Sans', 'Arial', sans-serif;
$rkv-font-family-sans: $acumin-pro;
// $rkv-font-family-serif: 'Georgia', serif;

// HTML tag.
$rkv-font-family-default: $rkv-font-family-sans;

// Headings.
$rkv-font-family-headings: $united-sans;
$rkv-font-family-headings-condensed: $united-sans-condensed;
$rkv-font-family-h1: $rkv-font-family-headings;
$rkv-font-family-h2: $rkv-font-family-headings;
$rkv-font-family-h3: $rkv-font-family-headings;
$rkv-font-family-h4: $rkv-font-family-headings;
$rkv-font-family-h5: $rkv-font-family-headings;
$rkv-font-family-h6: $rkv-font-family-headings;

// ==========
// Font size.
// ==========

// Text.
$rkv-font-size-default: 16px;
$rkv-font-size-normal: $rkv-font-size-default + 2px;
$rkv-font-size-small: $rkv-font-size-default - 3px;
$rkv-font-size-medium: $rkv-font-size-default - 2px;
$rkv-font-size-large: $rkv-font-size-default + 4px;
$rkv-font-size-huge: $rkv-font-size-default + 54px;

// Headings.
$rkv-font-size-h1: 40px;
$rkv-font-size-h2: 40px;
$rkv-font-size-h3: 25px;
$rkv-font-size-h4: 22px;
$rkv-font-size-h5: 18px;
$rkv-font-size-h6: $rkv-font-size-default;

// Text.
$rkv-line-height-default: 1;
$rkv-line-height-normal: 1.7777777778;
$rkv-line-height-small: inherit;
$rkv-line-height-medium: inherit;
$rkv-line-height-large: inherit;
$rkv-line-height-huge: 1;

// Headings.
$rkv-line-height-headings: inherit;
$rkv-line-height-h1: 1.1;
$rkv-line-height-h2: 1.1875;
$rkv-line-height-h3: 1.28;
$rkv-line-height-h4: 1.3636363636;
$rkv-line-height-h5: 1.5;
$rkv-line-height-h6: 1.5625;

// ============
// Font weight.
// ============

// Headings.
$rkv-font-weight-headings: 400;
$rkv-font-weight-h1: $rkv-font-weight-headings;
$rkv-font-weight-h2: $rkv-font-weight-headings;
$rkv-font-weight-h3: $rkv-font-weight-headings;
$rkv-font-weight-h4: 600;
$rkv-font-weight-h5: 600;
$rkv-font-weight-h6: 700;

// ========
// Gutters.
// ========

// prettier-ignore
$rkv-gutter: (
	$rkv-font-size-default * $rkv-line-height-default
);

// prettier-ignore
$rkv-gutter-half: (
	math.div($rkv-gutter, 2)
 );

// prettier-ignore
$rkv-gutter-quarter: (
	math.div($rkv-gutter, 4)
);

// prettier-ignore
$rkv-gutter-double: (
	$rkv-gutter * 2
);

// prettier-ignore
$rkv-gutter-triple: (
 	$rkv-gutter * 3
 );

// prettier-ignore
$rkv-gutter-quadruple: (
	$rkv-gutter * 4
);

// ===================
// Text block spacing.
// ===================

// Text.
$rkv-margin-bottom-default: 24px;
// prettier-ignore
$rkv-grid-breakpoints: (
	xs: 0,
	sm: 568px,
	md: 768px,
	lg: 1440px,
	xl: 1920px,
);


$rkv-max-width-container: 1920px;

$rkv-app-main-padding-top: 0;
$rkv-app-main-padding-bottom: 0;

// ==============
// Entry content.
// ==============

$rkv-max-width-entry-content: 880px;
$rkv-max-width-wide-entry-content: 1344px;

$rkv-entry-meta-font-size: $rkv-font-size-default;
$rkv-entry-meta-font-weight: 300;

$rkv-button-border-radius: 0;

$rkv-button-font-size: $rkv-font-size-default;
$rkv-button-font-family: $acumin-pro;
$rkv-button-font-weight: 400;

$rkv-button-opacity-hover: 1;

$rkv-button-box-shadow: none;
$rkv-button-box-shadow-hover: none;

$rkv-button-secondary-box-shadow: $rkv-button-box-shadow;
$rkv-button-secondary-box-shadow-hover: $rkv-button-box-shadow-hover;

$rkv-button-alert-box-shadow: $rkv-button-box-shadow;
$rkv-button-alert-box-shadow-hover: $rkv-button-box-shadow-hover;

$rkv-button-outline-box-shadow: $rkv-button-box-shadow;
$rkv-button-outline-box-shadow-hover: $rkv-button-box-shadow-hover;

$rkv-media-border-radius: 0;

// =============
// Figure block.
// =============

$rkv-block-figure-border-radius: 0;
$rkv-block-figure-figcaption-font-family: $rkv-font-family-sans;
$rkv-block-figure-figcaption-font-size: $rkv-font-size-default;
$rkv-block-figure-figcaption-font-weight: 300;
$rkv-block-figure-figcaption-line-height: 1.5625;
$rkv-block-figure-figcaption-text-align: left;

$rkv-alignfull-padding-left: $rkv-gutter;
$rkv-alignfull-padding-right: $rkv-gutter;

$rkv-box-border-radius: $-rkv-border-radius-default;

$rkv-app-header-height: 94.5px;

$rkv-mobile-menu-transition-duration: 0.3s;

@mixin mq($from: null, $until: null, $feature: 'width') {
    $breakpoints: (
        xs: 0,
        sm: 568px,
        md: 768px,
        lg: 1440px,
        xl: 1920px,
    );
  
    $from-value: null;
    $until-value: null;
  
    // Determine $from and $until values
    @if $from {
      @if map-has-key($breakpoints, $from) {
        $from-value: map-get($breakpoints, $from);
      } @else {
        @warn "Invalid from breakpoint specified: #{$from}. Please use one of: #{map-keys($breakpoints)}.";
      }
    }
  
    @if $until {
      @if map-has-key($breakpoints, $until) {
        $until-value: map-get($breakpoints, $until);
      } @else {
        @warn "Invalid until breakpoint specified: #{$until}. Please use one of: #{map-keys($breakpoints)}.";
      }
    }
  
    // Construct media query
    @if $from-value and $until-value {
      @media #{
          "(min-#{$feature}: #{$from-value}) and (max-#{$feature}: #{$until-value})"
        } {
        @content;
      }
    } @else if $from-value {
      @media #{
          "(min-#{$feature}: #{$from-value})"
        } {
        @content;
      }
    } @else if $until-value {
      @media #{
          "(max-#{$feature}: #{$until-value})"
        } {
        @content;
      }
    } @else {
      @warn "Invalid usage. Please specify either $from or $until.";
    }
  }
  




