!function(){"use strict";var e,t={109:function(){var e=window.React,t=window.wp.blocks,n=window.wp.blockEditor,l=window.wp.i18n,r=window.wp.components,o=JSON.parse('{"UU":"purdue/storytelling-qa-block"}');window.wp.primitives;(0,t.registerBlockType)(o.UU,{icon:()=>(0,e.createElement)("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 640 640"},(0,e.createElement)("path",{d:"M528 320C528 205.1 434.9 112 320 112C205.1 112 112 205.1 112 320C112 434.9 205.1 528 320 528C434.9 528 528 434.9 528 320zM64 320C64 178.6 178.6 64 320 64C461.4 64 576 178.6 576 320C576 461.4 461.4 576 320 576C178.6 576 64 461.4 64 320zM320 240C302.3 240 288 254.3 288 272C288 285.3 277.3 296 264 296C250.7 296 240 285.3 240 272C240 227.8 275.8 192 320 192C364.2 192 400 227.8 400 272C400 319.2 364 339.2 344 346.5L344 350.3C344 363.6 333.3 374.3 320 374.3C306.7 374.3 296 363.6 296 350.3L296 342.2C296 321.7 310.8 307 326.1 302C332.5 299.9 339.3 296.5 344.3 291.7C348.6 287.5 352 281.7 352 272.1C352 254.4 337.7 240.1 320 240.1zM288 432C288 414.3 302.3 400 320 400C337.7 400 352 414.3 352 432C352 449.7 337.7 464 320 464C302.3 464 288 449.7 288 432z"})),edit:t=>{const{id:o,question:a,answer:c,background:i}=t.attributes,{setAttributes:s}=t,u=(0,n.useBlockProps)({className:`storytelling-content-block section has-background-${i}`});return(0,n.useInnerBlocksProps)({className:"storytelling-content-block__inner"},{templateLock:!1}),[(0,e.createElement)(n.InspectorControls,{key:"1"},(0,e.createElement)(r.PanelBody,{title:(0,l.__)("Background Settings","purdue-home-theme-child-contenthub")},(0,e.createElement)(r.PanelRow,null,(0,e.createElement)(r.SelectControl,{label:"Choose the background of this slide.",value:i,options:[{label:"White",value:"grey-lighter-alt"},{label:"Black",value:"black"},{label:"Grey",value:"grey-lighter"},{label:"Rush Gold",value:"rush-gold"},{label:"Steel Gray",value:"dark-gray"},{label:"Boilermaker Gold",value:"gold"}],onChange:e=>s({background:e})})))),(0,e.createElement)("div",{...u,key:"2"},(0,e.createElement)("div",{className:"storytelling-qa-block__qa"},(0,e.createElement)("p",null,(0,e.createElement)("span",null,"Q+A"))),(0,e.createElement)(n.RichText,{tagName:"p",className:"qa-question",value:a,placeholder:"Add question…",onChange:e=>s({question:e}),allowedFormats:["core/bold","core/italic"]}),(0,e.createElement)(n.RichText,{tagName:"p",className:"qa-anwswer",value:c,placeholder:"Add answer…",onChange:e=>s({answer:e})}))]},save:()=>(0,e.createElement)(n.InnerBlocks.Content,null)})}},n={};function l(e){var r=n[e];if(void 0!==r)return r.exports;var o=n[e]={exports:{}};return t[e](o,o.exports,l),o.exports}l.m=t,e=[],l.O=function(t,n,r,o){if(!n){var a=1/0;for(u=0;u<e.length;u++){n=e[u][0],r=e[u][1],o=e[u][2];for(var c=!0,i=0;i<n.length;i++)(!1&o||a>=o)&&Object.keys(l.O).every(function(e){return l.O[e](n[i])})?n.splice(i--,1):(c=!1,o<a&&(a=o));if(c){e.splice(u--,1);var s=r();void 0!==s&&(t=s)}}return t}o=o||0;for(var u=e.length;u>0&&e[u-1][2]>o;u--)e[u]=e[u-1];e[u]=[n,r,o]},l.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},function(){var e={752:0,712:0};l.O.j=function(t){return 0===e[t]};var t=function(t,n){var r,o,a=n[0],c=n[1],i=n[2],s=0;if(a.some(function(t){return 0!==e[t]})){for(r in c)l.o(c,r)&&(l.m[r]=c[r]);if(i)var u=i(l)}for(t&&t(n);s<a.length;s++)o=a[s],l.o(e,o)&&e[o]&&e[o][0](),e[o]=0;return l.O(u)},n=self.webpackChunkpurdue_home_theme_child=self.webpackChunkpurdue_home_theme_child||[];n.forEach(t.bind(null,0)),n.push=t.bind(null,n.push.bind(n))}();var r=l.O(void 0,[712],function(){return l(109)});r=l.O(r)}();