.wp-block-purdue-storytelling-side-by-side{display:block;color:#000;margin:1rem auto}.wp-block-purdue-storytelling-side-by-side .block-editor-inner-blocks{display:flex;width:100%}.wp-block-purdue-storytelling-side-by-side .block-editor-inner-blocks .block-editor-block-list__layout{display:flex;flex-grow:1}.wp-block-purdue-storytelling-side-by-side .block-editor-inner-blocks .block-editor-block-list__layout:not(.is-desktop){display:flex !important;flex-wrap:wrap}.wp-block-purdue-storytelling-side-by-side .block-editor-inner-blocks .block-editor-block-list__layout{margin-bottom:-0.75rem;margin-top:-0.75rem}.wp-block-purdue-storytelling-side-by-side .block-editor-inner-blocks .bulma-blocks-editor-column{display:flex;justify-content:center}
