@import '../../style/front-end/variables.scss';

.storytelling-content-block {
    text-align: center;
    font-size: 1.25rem;
    border-radius: 4px;
    display: flex;
    flex-direction: column;
    flex-grow: 1;

    p:nth-of-type(odd) {
        font-family: $united-sans;
        font-weight: 700;
        font-size: 1.25rem;
        text-transform: uppercase;
        margin-bottom: 0;
    }

    &.has-background-black {
        p:nth-of-type(odd) {
            color: $boiler-gold;
        }

        p:nth-of-type(even) {
            color: #ffffff;
        }

    }

    

}

.storytelling-content-block::before {
  pointer-events: none;
}