.purdue-storytelling-side-by-side{flex-wrap:nowrap;display:flex;margin-bottom:3rem !important}.purdue-storytelling-side-by-side .wp-block-image{height:100%}.purdue-storytelling-side-by-side .wp-block-image img{height:100% !important;object-fit:cover}.purdue-storytelling-side-by-side .column{display:flex}
