!function(){"use strict";var e,t={784:function(){var e=window.React,t=window.wp.blocks,n=window.wp.blockEditor;window.wp.i18n,window.wp.components;const r=["purdue/storytelling-column",["purdue/storytelling-content"]],o=[["purdue/storytelling-column"],["purdue/storytelling-column"]];var l=JSON.parse('{"UU":"purdue/storytelling-side-by-side"}'),i=window.wp.primitives;(0,t.registerBlockType)(l.UU,{icon:()=>(0,e.createElement)(i.SVG,{id:"Layer_1","data-name":"Layer 1",xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 100 100"},(0,e.createElement)("defs",null),(0,e.createElement)("g",{id:"clone",className:"cls-1"},(0,e.createElement)("g",{className:"cls-1"},(0,e.createElement)(i.Path,{className:"cls-2",d:"M100,9.38V71.87a9.38,9.38,0,0,1-9.37,9.38H81.25v9.37A9.38,9.38,0,0,1,71.87,100H9.37A9.38,9.38,0,0,1,0,90.62V28.13a9.38,9.38,0,0,1,9.37-9.38h9.38V9.38A9.38,9.38,0,0,1,28.12,0H90.63A9.38,9.38,0,0,1,100,9.38ZM71.87,89.45v-8.2H28.12a9.38,9.38,0,0,1-9.37-9.38V28.13h-8.2A1.17,1.17,0,0,0,9.37,29.3V89.45a1.17,1.17,0,0,0,1.18,1.17H70.7A1.17,1.17,0,0,0,71.87,89.45ZM90.63,70.7V10.55a1.17,1.17,0,0,0-1.18-1.17H29.3a1.17,1.17,0,0,0-1.18,1.17V70.7a1.17,1.17,0,0,0,1.18,1.17H89.45A1.17,1.17,0,0,0,90.63,70.7Z",transform:"translate(0 0)"})))),edit:t=>{const{setAttributes:l}=t,{id:i}=t.attributes,s=(0,n.useBlockProps)();return l({id:t.clientId}),(0,e.createElement)("div",{...s},(0,e.createElement)(n.InspectorControls,null),(0,e.createElement)("div",{className:"columns is-gapless purdue-storytelling-side-by-side-editor"},(0,e.createElement)(n.InnerBlocks,{allowedBlocks:r,template:o,templateLock:!1,templateInsertUpdatesSelection:!1})))},save:()=>(0,e.createElement)(n.InnerBlocks.Content,null)})}},n={};function r(e){var o=n[e];if(void 0!==o)return o.exports;var l=n[e]={exports:{}};return t[e](l,l.exports,r),l.exports}r.m=t,e=[],r.O=function(t,n,o,l){if(!n){var i=1/0;for(u=0;u<e.length;u++){n=e[u][0],o=e[u][1],l=e[u][2];for(var s=!0,a=0;a<n.length;a++)(!1&l||i>=l)&&Object.keys(r.O).every(function(e){return r.O[e](n[a])})?n.splice(a--,1):(s=!1,l<i&&(i=l));if(s){e.splice(u--,1);var c=o();void 0!==c&&(t=c)}}return t}l=l||0;for(var u=e.length;u>0&&e[u-1][2]>l;u--)e[u]=e[u-1];e[u]=[n,o,l]},r.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},function(){var e={301:0,153:0};r.O.j=function(t){return 0===e[t]};var t=function(t,n){var o,l,i=n[0],s=n[1],a=n[2],c=0;if(i.some(function(t){return 0!==e[t]})){for(o in s)r.o(s,o)&&(r.m[o]=s[o]);if(a)var u=a(r)}for(t&&t(n);c<i.length;c++)l=i[c],r.o(e,l)&&e[l]&&e[l][0](),e[l]=0;return r.O(u)},n=self.webpackChunkpurdue_home_theme_child=self.webpackChunkpurdue_home_theme_child||[];n.forEach(t.bind(null,0)),n.push=t.bind(null,n.push.bind(n))}();var o=r.O(void 0,[153],function(){return r(784)});o=r.O(o)}();