.has-white-color{color:#fff !important}.has-black-color{color:#000 !important}.has-aged-gold-color{color:#8e6f3e !important}.has-boiler-gold-color{color:#cfb991 !important}.has-rush-gold-color{color:#daaa00 !important}.has-field-gold-color{color:#ddb945 !important}.has-dust-gold-color{color:#ebd99f !important}.has-steel-gray-color{color:#555960 !important}.has-cool-gray-color{color:#6f727b !important}.has-steam-gray-color{color:#c4bfc0 !important}.has-railway-gray-color{color:#9d9795 !important}.has-opaque-color{color:rgba(0,0,0,.65) !important}.has-transparent-color{color:rgba(0,0,0,0) !important}.has-white-background-color{background-color:#fff !important}.has-black-background-color{background-color:#000 !important}.has-aged-gold-background-color{background-color:#8e6f3e !important}.has-boiler-gold-background-color{background-color:#cfb991 !important}.has-rush-gold-background-color{background-color:#daaa00 !important}.has-field-gold-background-color{background-color:#ddb945 !important}.has-dust-gold-background-color{background-color:#ebd99f !important}.has-steel-gray-background-color{background-color:#555960 !important}.has-cool-gray-background-color{background-color:#6f727b !important}.has-steam-gray-background-color{background-color:#c4bfc0 !important}.has-railway-gray-background-color{background-color:#9d9795 !important}.has-opaque-background-color{background-color:rgba(0,0,0,.65) !important}.has-transparent-background-color{background-color:rgba(0,0,0,0) !important}.has-background-black-ter{background-color:#555960 !important}.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}hr.wp-block-separator{height:1px !important}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.united-sans-font{font-family:"United Sans",Impact,"Arial Black","sans serif" !important}strong{color:inherit !important}.storytelling-content-block{text-align:center;font-size:1.25rem;border-radius:4px;display:flex;flex-direction:column;flex-grow:1}.storytelling-content-block p:nth-of-type(odd){font-family:"United Sans",Impact,"Arial Black","sans serif";font-weight:700;font-size:1.25rem;text-transform:uppercase;margin-bottom:0}.storytelling-content-block.has-background-black p:nth-of-type(odd){color:#cfb991}.storytelling-content-block.has-background-black p:nth-of-type(even){color:#fff}.storytelling-content-block::before{pointer-events:none}
