.post-content {
  .post-content__video-hero {
    width: 100%;
    .purdue-home-cta-card .image:after {
      z-index: 1;
    }
  }
  h1 {
    @include desktop {
      font-size: 3rem !important;
      line-height: 1.167 !important;
    }
  }
  h2 {
    @include tablet {
      font-size: 2.25rem !important;
      line-height: 1.167 !important;
      font-family: $acumin-pro !important;
    }
  }
  h1,
  &__subheading {
    z-index: 2;
    position: relative;
    color: $white;
  }
  &__thumbnail:before {
    content: "";
    background: $black;
    position: absolute;
    bottom: 50%;
    width: 100vw;
    height: 150vh;
    z-index: -1;
  }
  &__thumbnail--caption {
    position: relative;
    &:before {
      @include mobile {
        content: "";
        background: $white;
        position: absolute;
        bottom: 100%;
        width: calc(100vw + 4rem);
        height: 30vw;
        z-index: -1;
        right: -2rem;
      }
    }
    &:after {
      @include mobile {
        content: "";
        background: $white;
        position: absolute;
        top: 0;
        width: calc(100vw + 4rem);
        height: 100%;
        z-index: -1;
        right: -2rem;
      }
    }
  }
  &__thumbnail img {
    z-index: 1;
  }
  .wp-block-image figcaption {
    display: block;
  }
  .purdue-post-author__footer {
    margin-top: 3rem;
    padding: 2rem 0;
    border-top: 1px solid $railway-gray;
    border-bottom: 1px solid $railway-gray;
    display: flex;

    @include mobile {
      display: block;
    }
    .purdue-post-author__description--name {
      a {
        color: $black;
        text-decoration: none;
        text-transform: uppercase;
      }
      margin-bottom: 0;
    }
    .purdue-post-author__image {
      margin-right: 1.5rem;
      margin-top: 0.5rem;
      img {
        min-width: 90px;
        max-width: 90px;
        height: auto;
        border-radius: 4px;
      }
      @include mobile {
        margin-top: 0;
        margin-bottom: 0.5rem;
      }
    }
  }
  .purdue-parallax-image-wrap {
    margin-top: 3rem;
    margin-bottom: 3rem;
    @include mobile {
      margin-top: 2rem;
      margin-bottom: 2rem;
    }
    .purdue-parallax-image {
      min-width: 100vw;
      min-height: 100vh;
      background-position: center center;
      background-attachment: fixed;
      background-repeat: no-repeat;
      background-size: cover;
      overflow: hidden;
      height: 0;
      position: relative;
      margin-top: 0 !important;
      margin-bottom: 0 !important;
      @include touch {
        min-height: 650px;
        min-width: 0;
        background-attachment: scroll;
      }
      @include mobile {
        min-height: 0;
      }
    }
    .purdue-parallax-image__caption {
      border-left: 1px solid #c4bfc0;
      color: $steel-gray;
      margin: 1.5rem 0 0 1.5rem;
      padding: 0 1.5rem 0 1.5rem;
      @include mobile {
        margin: 1.5rem 0 0 0;
        padding: 0 1.5rem 0 1rem;
      }
    }
  }
}
.main-content.podcast-post {
  background: $black;
  .post-content {
    .icon.print-icon {
      svg {
        path:first-child {
          fill: $white;
        }
        path:last-child {
          fill: $black;
        }
      }
      &:hover {
        svg {
          path:first-child {
            fill: $boiler-gold;
          }
        }
      }
    }
    h1,
    &__subheading {
      color: $black;
    }
    &__thumbnail:before {
      background: $white;
      z-index: 0;
    }
    &__thumbnail--caption:before {
      @include mobile {
        background: $black;
      }
    }
  }
  .post-content__byline,
  .post-content__byline--date .post-author-individual {
    color: $white;
  }
  .post-content__byline--share a.icon.is-medium {
    &:hover {
      color: $boiler-gold;
      i,
      svg {
        fill: $boiler-gold;
        color: $boiler-gold;
      }
    }
    i,
    svg {
      fill: $white;
      color: $white;
    }
  }

  .purdue-post-author__footer {
    .purdue-post-author__description--name {
      a {
        color: $white;
      }
    }
  }
}
.icon.print-icon {
  &:hover {
    svg {
      path:first-child {
        fill: $aged-gold;
      }
    }
  }
}
.section.tpp-topic--social {
  padding-bottom: 0;
  @include touch {
    padding-top: 0 !important;
  }
  .level.post-content__byline {
    margin-bottom: 0;
    .level-right.post-content__byline--share {
      @include touch {
        margin-top: 3rem !important;
      }
      @include mobile {
        margin-top: 2rem !important;
      }
    }
  }
}
.single-topic {
  .purdue-home-cta-banner.purdue-home-teritary-hero {
    .image {
      img {
        object-position: top;
      }
      &:after {
        background-color: rgba(255, 255, 255, 0.75);
      }
    }
    h1,
    p {
      color: $black;
    }
  }
}
.tpp-topics {
  h2:not(
      .purdue-home-cta-banner__subheader,
      .purdue-home-cta-banner__header,
      .tagged-header
    ) {
    font-size: 2.25rem !important;
    line-height: 1.167 !important;
    font-family: $acumin-pro !important;
  }
  .purdue-home-cta-banner.purdue-home-teritary-hero .section .container {
    display: flex;
    flex-direction: column;
    align-items: center;
    justify-content: center;
    min-height: 208px;
    @include mobile {
      min-height: 146px;
    }
  }
  .has-gray-background.post-related-stories {
    .purdue-home-cta-card.purdue-home-cta-card--story {
      background: $black;
      .flex-container--align-center {
        .purdue-home-cta-grid__card-subtitle {
          color: $white;
          span:not(:first-child):before {
            border-left: 2px solid $white;
          }
        }
        .purdue-home-cta-grid__card-title {
          color: $white;
        }
      }
    }
    .post-type-post .purdue-posttype-tag:before {
      background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='27' height='19' viewBox='0 0 27 19' fill='none'%3E%3Cpath d='M4.3 2.96224C4.461 2.89924 4.6542 2.82949 4.87845 2.75862C5.99327 2.41477 7.15611 2.24321 8.325 2.25013C9.49389 2.24321 10.6567 2.41477 11.7715 2.75862C11.9958 2.82949 12.189 2.89924 12.35 2.96224V15.2019C11.0455 14.8131 9.68867 14.6185 8.325 14.6248C6.646 14.6248 5.27865 14.9038 4.3 15.2019V2.96224ZM13.5 0.99579C13.1665 0.852407 12.8256 0.725869 12.4788 0.616674C11.1354 0.200924 9.73396 -0.00707633 8.325 0.000189865C6.5701 0.000189865 5.15675 0.305057 4.1712 0.616674C3.77882 0.739717 3.3944 0.885854 3.02005 1.05429C2.8809 1.11723 2.74397 1.18477 2.6095 1.25678L2.58075 1.27253L2.5704 1.27816L2.56695 1.28041C2.56465 1.28266 2.28175 1.44578 2.5635 1.28266C2.39183 1.38223 2.24961 1.52378 2.15081 1.69341C2.05201 1.86304 2.00003 2.0549 2 2.25013V16.8748C2.00004 17.0733 2.05379 17.2683 2.15582 17.44C2.25784 17.6117 2.40449 17.7538 2.58087 17.8521C2.75725 17.9504 2.95707 18.0012 3.16004 17.9995C3.36302 17.9978 3.5619 17.9435 3.7365 17.8422L3.73075 17.8456L3.7342 17.8445L3.73535 17.8434L3.7779 17.8209C3.82045 17.7984 3.8906 17.7646 3.9872 17.7196C4.1827 17.6319 4.4817 17.5081 4.87845 17.3821C5.99333 17.0387 7.15617 16.8675 8.325 16.8748C9.49383 16.8675 10.6567 17.0387 11.7715 17.3821C12.0753 17.477 12.3729 17.5897 12.6628 17.7196C12.7496 17.759 12.8351 17.801 12.9192 17.8456M12.9192 17.8456L12.9158 17.8445L12.9146 17.8434C13.2758 18.0515 13.7242 18.0515 14.0853 17.8434L14.1279 17.8209C14.1704 17.7984 14.2406 17.7646 14.3372 17.7196C14.6271 17.5897 14.9247 17.477 15.2284 17.3821C16.3433 17.0387 17.5062 16.8675 18.675 16.8748C19.8438 16.8675 21.0067 17.0387 22.1215 17.3821C22.4253 17.477 22.7229 17.5897 23.0128 17.7196C23.098 17.7583 23.182 17.7996 23.2646 17.8434C23.4393 17.9444 23.6382 17.9984 23.8411 18C24.044 18.0015 24.2437 17.9505 24.4199 17.8521C24.5962 17.7538 24.7426 17.6115 24.8445 17.4399C24.9464 17.2682 25 17.0733 25 16.8748V2.25013C25 2.0549 24.948 1.86304 24.8492 1.69341C24.7504 1.52378 24.6082 1.38223 24.4365 1.28266L24.4342 1.28153L24.4296 1.27816L24.4181 1.27253L24.3905 1.25678C24.256 1.18475 24.1191 1.11722 23.9799 1.05429C23.606 0.885917 23.2219 0.73978 22.83 0.616674C21.4862 0.200808 20.0843 -0.00719353 18.675 0.000189865C16.9212 0.000189865 15.5067 0.305057 14.5212 0.616674C14.1743 0.725594 13.8334 0.852138 13.5 0.99579M22.7 2.96224V15.2019C21.3955 14.8131 20.0387 14.6185 18.675 14.6248C16.996 14.6248 15.6286 14.9038 14.65 15.2019V2.96224C14.811 2.89924 15.0042 2.82949 15.2284 2.75862C16.3433 2.41477 17.5061 2.24321 18.675 2.25013C19.8439 2.24321 21.0067 2.41477 22.1215 2.75862C22.3458 2.82949 22.539 2.89924 22.7 2.96224ZM23.2635 3.21873L23.2693 3.22098H23.2681L23.2635 3.21873ZM23.2646 17.8434L23.2681 17.8456L23.2658 17.8434' fill='%23CFB991'/%3E%3C/svg%3E");
    }
    .post-type-podcast .purdue-posttype-tag:before {
      background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='23' height='19' viewBox='0 0 23 19' fill='none'%3E%3Cpath d='M11.5 0C5.69711 0 1 4.85586 1 10.8571V12.8929C0.999997 13.1449 1.06787 13.392 1.19601 13.6064C1.32416 13.8208 1.50751 13.994 1.72553 14.1067L2.31545 14.4117C2.39794 16.9602 4.42156 19 6.90625 19H7.89062C8.43429 19 8.875 18.5443 8.875 17.9821V10.5179C8.875 9.9557 8.43429 9.5 7.89062 9.5H6.90625C5.62074 9.5 4.45881 10.0462 3.625 10.9261V10.8571C3.625 6.36716 7.15772 2.71429 11.5 2.71429C15.8423 2.71429 19.375 6.36716 19.375 10.8571V10.9261C18.5412 10.0462 17.3793 9.5 16.0938 9.5H15.1094C14.5657 9.5 14.125 9.9557 14.125 10.5179V17.9821C14.125 18.5443 14.5657 19 15.1094 19H16.0938C18.5784 19 20.6021 16.9601 20.6845 14.4117L21.2744 14.1067C21.4925 13.994 21.6758 13.8208 21.804 13.6064C21.9321 13.392 22 13.1449 22 12.8929V10.8571C22 4.85692 17.3039 0 11.5 0Z' fill='%23cfb991'/%3E%3C/svg%3E");
    }
    .post-type-video .purdue-posttype-tag:before {
      background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='23' height='21' viewBox='0 0 23 21' fill='none'%3E%3Cg clip-path='url(%23clip0_82_582)'%3E%3Cpath d='M16.3189 13.7878V16.8516C16.3189 17.5757 15.7264 18.1668 15.0026 18.1668H1.3166C0.59276 18.1668 0 17.5757 0 16.8516V4.14816C0 3.42432 0.59247 2.83301 1.3166 2.83301H15.0026C15.7264 2.83301 16.3189 3.42403 16.3189 4.14816V7.17344V7.1311L23.2 3.90688V17.0421L16.3189 13.7878Z' fill='%23cfb991'/%3E%3C/g%3E%3Cdefs%3E%3CclipPath id='clip0_82_582'%3E%3Crect width='23' height='21' fill='white'/%3E%3C/clipPath%3E%3C/defs%3E%3C/svg%3E");
    }
  }
}
.rkv-default-archive-card-slider__wrapper.post-related-stories
  .purdue-home-link-cards__slider
  .slider-controls {
  justify-content: center;
}
.purdue-home-cta-card.purdue-home-cta-card--story.post-type-video
  .purdue-home-button {
  font-size: 0px;
}
.purdue-home-cta-card.purdue-home-cta-card--story.post-type-video
  .purdue-home-button:before {
  content: "Watch";
  font-size: 18px !important;
}
.purdue-home-cta-card.purdue-home-cta-card--story.post-type-podcast
  .purdue-home-button {
  font-size: 0px;
}
.purdue-home-cta-card.purdue-home-cta-card--story.post-type-podcast
  .purdue-home-button:before {
  content: "Listen";
  font-size: 18px !important;
}
.purdue-home-cta-card.purdue-home-cta-card--story.post-type-article
  .purdue-home-button {
  font-size: 0px;
}
.purdue-home-cta-card.purdue-home-cta-card--story.post-type-article
  .purdue-home-button:before {
  content: "Read";
  font-size: 18px !important;
}
.purdue-link-card.purdue-home-cta-grid.purdue-home-post-grid {
  margin-top: 3rem;
  margin-bottom: 3rem;
  @include mobile {
    margin-top: 2rem;
    margin-bottom: 2rem;
  }
}

.post-content__readtime{
  
  position: absolute;
  left: 137px;

  .modal-trigger{
    &:hover{
      i{
        color: $aged-gold;
      }
    }
  }

  @media screen and (max-width: 1407px) {
    left: 40px;
  }

  @media screen and (max-width: 1215px) {
    left: -56px;
  }

  @media screen and (max-width: 1100px) {
    display: flex;
    justify-content: flex-start;
    position: relative;
    left: auto;

    &.is-hidden-touch{
      display: none;
    }

    &.is-hidden-desktop{
      display: flex !important;
    }
  }
  
  &.extra-space{
    margin-top: 3.5rem;
  }

  .columns{
    flex-direction: column;
    @media screen and (max-width: 1100px) {
      display: flex;
      flex-direction: row;

      .column{
        flex-direction: row;
        align-items: center;
      }
    }
  }

  & .modal-trigger{
    align-items: flex-end;
  }
  
  .column{    
    display: flex;
    flex-direction: column;
    justify-content: right;
    text-align: right;
    text-transform: uppercase;
    color: $steel-gray;
    font-family: $united-sans-condensed;
    font-weight: 600;
    margin-bottom: 0.5rem;

    i{
      padding-bottom: 0.25rem;
    }

    @media screen and (max-width: 1100px) {
      width: 125px;

      i{
        padding-top: 0.25rem;
        padding-right: 0.5rem;
      }
    }

    .fa-solid{
      font-size: 1.5rem;
      color: #000;
    }

  }
    
}

.purdue-home-quote__title{
  margin-top: 0 !important;
}


/* customize additional css */
@media (min-width: 1408px){
  .tpp-topics .alignwide{
    padding-left:0;
    padding-right:0;
  }
  }
  @media (max-width: 1407px){
  .tpp-topics .alignwide{
      max-width: calc(100vw - 40px);
      margin-left: calc(-50vw + 50% + 20px);
      margin-right: calc(-50vw + 50% + 20px);
    }
  }
  .purdue-home-quote .purdue-home-quote-content{
    max-width:100% !important;
  }
  .section.image-slider-wrapper{
  overflow:hidden;
  }
/* fixes text shadow on captions  */
.wp-block-gallery.has-nested-images figure.wp-block-image figcaption {
  text-shadow: none !important;
}