!function(){"use strict";var e,t={221:function(){var e=window.wp.blocks,t=window.React,n=(window.wp.i18n,window.wp.components,window.wp.blockEditor),o=window.wp.element,r=window.wp.data,l=JSON.parse('{"apiVersion":2,"name":"purdue/storytelling-column","title":"Storytelling - Column","category":"purdue","icon":"welcome-add-page","description":"Column block for the Storytelling side by side block.","parent":["purdue/storytelling-side-by-side","purdue/storytelling-content-block"],"attributes":{"blockId":{"type":"string","default":""}},"supports":{"className":true,"inserter":true},"editorScript":"file:./index.js","editorStyle":"file:./editor.scss","style":"file:./style.scss"}');(0,e.registerBlockType)(l,{edit:function(e,l){const{context:c}=e,i=(0,n.useBlockProps)(),s=e.clientId&&wp.data.select("core/block-editor").getBlock(e.clientId).innerBlocks;return((0,r.select)("core/block-editor").getBlock(e.clientId)?.innerBlocks||[])[0],(0,o.useEffect)(()=>{e.attributes.blockId||e.setAttributes({blockId:e.clientId})},[]),(0,t.createElement)("div",{...i,id:`block-${e.attributes.blockId}`,className:"bulma-blocks-editor-column column is-half is-gapless"},(0,t.createElement)(n.InnerBlocks,{templateLock:!1,allowedBlocks:["core/image","purdue/storytelling-content-block","purdue/storytelling-qa-block"],template:[["core/paragraph",{placeholder:"Add Content Block"}]],renderAppender:s?void 0:()=>(0,t.createElement)(n.InnerBlocks.ButtonBlockAppender,null)}))},save:function(e){return(0,t.createElement)("div",{className:"column is-half"},(0,t.createElement)(n.InnerBlocks.Content,null))}})}},n={};function o(e){var r=n[e];if(void 0!==r)return r.exports;var l=n[e]={exports:{}};return t[e](l,l.exports,o),l.exports}o.m=t,e=[],o.O=function(t,n,r,l){if(!n){var c=1/0;for(d=0;d<e.length;d++){n=e[d][0],r=e[d][1],l=e[d][2];for(var i=!0,s=0;s<n.length;s++)(!1&l||c>=l)&&Object.keys(o.O).every(function(e){return o.O[e](n[s])})?n.splice(s--,1):(i=!1,l<c&&(c=l));if(i){e.splice(d--,1);var u=r();void 0!==u&&(t=u)}}return t}l=l||0;for(var d=e.length;d>0&&e[d-1][2]>l;d--)e[d]=e[d-1];e[d]=[n,r,l]},o.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},function(){var e={821:0,625:0};o.O.j=function(t){return 0===e[t]};var t=function(t,n){var r,l,c=n[0],i=n[1],s=n[2],u=0;if(c.some(function(t){return 0!==e[t]})){for(r in i)o.o(i,r)&&(o.m[r]=i[r]);if(s)var d=s(o)}for(t&&t(n);u<c.length;u++)l=c[u],o.o(e,l)&&e[l]&&e[l][0](),e[l]=0;return o.O(d)},n=self.webpackChunkpurdue_home_theme_child=self.webpackChunkpurdue_home_theme_child||[];n.forEach(t.bind(null,0)),n.push=t.bind(null,n.push.bind(n))}();var r=o.O(void 0,[625],function(){return o(221)});r=o.O(r)}();