.photo-essay{
    display: flex; 
    flex-wrap: wrap;

    .is-12-desktop{
        text-align: center;
        figure>figcaption, .wp-block-image>figcaption{
            text-align: center;
            margin: 1.5rem auto 0 auto !important;
            width: auto;
            max-width: fit-content;
        }
    }

    .is-4-desktop:last-of-type{
        @media screen and (max-width: 1023px){
            width: 100%;
        }
    }

     .is-fullheight{
        .wp-block-image, img{
                height: calc(100%) !important;            
        }
    }

    .is-left, .is-right{
        .wp-block-image:not(:last-child) {
            margin-bottom: 1.5rem;
            @media screen and (max-width: 767px){
                margin-bottom: 0.75rem;
            }
        }
        .wp-block-image:not(:first-child)
        {
            margin-top: 1.5rem;
            @media screen and (max-width: 767px){
                margin-top: 0.75rem;
            }
        }
    }

    .column{
        @media screen and (max-width: 767px){
            padding: 12px 6px 0 !important;
            
        }
    }
}
