@import '../../style/front-end/variables.scss';

.storytelling-featured {
    position: relative;

    &::before {
        content: '';
        display: inline-block;
        background-image: url('./../../../images/Student-storytelling-texture-background.png');
        background-size: cover;
        background-repeat: no-repeat;
        background-position: center;
        position: absolute;
        top: 0;
        max-height: 75%;
        width: 90%;
        height: 100%;
        align-self: center;
        bottom: 0;
        border-radius: 4px;
        left: 0;
        right: 0;
        margin: 0 auto;
    }

    .featured-texture {
        display: none;
        position: absolute;
        width: 100%;
        padding: 2rem 0rem;
        left: 0;
        right: 0;
        bottom: 0;
        max-width: 80%;
        margin: 0 auto;

        img {
            height: 100%;
            object-fit: cover;
            min-height: 350px;
            border-radius: 4px;
        }
    }

    .featured-image-wrapper {
        z-index: 1;

        img {
            border-radius: 4px;
        }
    }

    .featured-content-wrapper {
        z-index: 2;
        position: relative;
        margin-top: 3rem;
    }

    .block-image-wrapper {
        z-index: 10;
        position: relative;
        background: white;
        padding-bottom: 2rem;
        width: 100%;

        img{
            object-fit: cover;
            width: 100%;
        }
    }

    .block-image-controls{
        padding: 1rem;
    }

    .block-list-appender.wp-block{
        background-color: #ffffff;
        margin-top: 1rem;
    }


}