.rkv-block-cover-card-slider[class] {
	padding: 0;
	position: relative;

	.rkv-block-cover-card-slider-slides {
		margin-bottom: 16px;
	}
	.cover-card-slider__item {
		height: 395px;
		width: 660px;
		@include mq($until: md) {
			height: 328px;
			width: 318px;
			box-shadow: 0px 3px 6px #00000029;
		}
		display: flex;
		justify-content: center;
		align-items: center;
		align-content: center;
		background-repeat: no-repeat;
		background-position: center center;
		background-size: 100%;
		transition: background-size 0.3s;
		@include mq($until: md) {
			background-size: 100% 190;
			background-position: top center;
			padding-top: 190px;
		}
		@include mq($from: md) {
			&:hover {
				background-size: 110%;
				.cover-card-slider__item__content {
					clip-path: inset(0 0);
					&.has-excerpt {
						grid-template-rows: 1fr 1fr 1fr;
					}
					.cover-card-slider__item__excerpt {
						opacity: 1;
					}
				}
			}
		}

		.cover-card-slider__item__content {
			text-align: center;
			background: $-purdue-white;
			@include mq($from: md) {
				background: rgba(255, 255, 255, 0.8);
				box-shadow: 0px 3px 6px #00000029;
				padding: 125px 0;
				transition: clip-path 0.3s;
				clip-path: inset(125px 124px);
			}
			width: 100%;
			height: 100%;
			display: grid;
			transition: all 0.3s;
			grid-template-rows: 1fr 1fr;
			&.has-excerpt {
				grid-template-rows: 1fr 0px 1fr;
			}
			justify-content: center;
			justify-items: center;
			align-items: center;
			align-content: center;
			overflow: hidden;
			position: relative;
			@include mq($from: md) {
				&:after {
					position: absolute;
					bottom: 0;
					right: 0;
					content: ' ';
					background-repeat: no-repeat;
					background-size: 28px 26px;
					width: 28px;
					height: 26px;
					margin: 25px;
					display: block;
					filter: invert(100%) brightness(48%);
					background-image: url("data:image/svg+xml,%3Csvg aria-hidden='true' focusable='false' data-prefix='fas' data-icon='newspaper' class='svg-inline--fa fa-newspaper fa-w-18' role='img' xmlns='http://www.w3.org/2000/svg' viewBox='0 0 576 512'%3E%3Cpath fill='currentColor' d='M552 64H88c-13.255 0-24 10.745-24 24v8H24c-13.255 0-24 10.745-24 24v272c0 30.928 25.072 56 56 56h472c26.51 0 48-21.49 48-48V88c0-13.255-10.745-24-24-24zM56 400a8 8 0 0 1-8-8V144h16v248a8 8 0 0 1-8 8zm236-16H140c-6.627 0-12-5.373-12-12v-8c0-6.627 5.373-12 12-12h152c6.627 0 12 5.373 12 12v8c0 6.627-5.373 12-12 12zm208 0H348c-6.627 0-12-5.373-12-12v-8c0-6.627 5.373-12 12-12h152c6.627 0 12 5.373 12 12v8c0 6.627-5.373 12-12 12zm-208-96H140c-6.627 0-12-5.373-12-12v-8c0-6.627 5.373-12 12-12h152c6.627 0 12 5.373 12 12v8c0 6.627-5.373 12-12 12zm208 0H348c-6.627 0-12-5.373-12-12v-8c0-6.627 5.373-12 12-12h152c6.627 0 12 5.373 12 12v8c0 6.627-5.373 12-12 12zm0-96H140c-6.627 0-12-5.373-12-12v-40c0-6.627 5.373-12 12-12h360c6.627 0 12 5.373 12 12v40c0 6.627-5.373 12-12 12z'%3E%3C/path%3E%3C/svg%3E");
				}
			}

			h4,
			.cover-card-slider__item__title {
				font-size: 25px;
				line-height: 1.2;
				font-weight: 600;
				font-family: $rkv-button-font-family;
				color: $-rkv-color-black;
				margin: 0 auto $rkv-gutter;
				text-align: center;
				width: 100%;
				@include mq($from: md) {
					padding: 0 124px;
				}
				align-self: end;
				a {
					text-decoration: none;
					color: inherit;
				}
			}
			.cover-card-slider__item__excerpt {
				text-align: center;
				font-size: $rkv-font-size-default;
				font-family: $rkv-button-font-family;
				line-height: 1.4375;
				letter-spacing: 0px;
				color: $-rkv-color-black;
				transition: opacity 0.3s;
				opacity: 0;
				min-height: 0;
				margin-bottom: $rkv-gutter-double;
				padding: 0 114px;
				position: relative;
				@include mq($until: md) {
					display: none;
				}
			}
			a.button {
				align-self: start;
				background: $-purdue-yellow-brighter;
				text-align: left;
				font-size: $rkv-font-size-default;
				font-family: $acumin-pro-semicondensed;
				font-weight: 600;
				padding: 15px 35px;
				line-height: 0.7;
				vertical-align: middle;
				color: $-purdue-black;
				border: 1px solid $-purdue-gray;
				text-decoration: none;
				height: auto;
				border-radius: $-rkv-border-radius-default;
				flex-grow: 0;
				&:hover {
					background: $-purdue-black;
					color: $-purdue-white;
				}
			}
		}
	}

	@include purdue_carousel_tinyslider_default(100%);

	// Editor

	.editor-styles-wrapper .is-root-container[class] & {
		width: 100%;
		.rkv-block-cover-card-slider-slides {
			width: 100%;
			display: flex;
			flex-wrap: nowrap;
			overflow-x: scroll;
			overflow-y: hidden;
			height: 395px;
			flex-direction: row;
			padding-bottom: 16px;
			margin-bottom: 16px;
			padding-left: 0;
			&::-webkit-scrollbar {
				height: 2px;
			}
			&::-webkit-scrollbar-track {
				background-color: $-purdue-black;
				border-radius: 0;
				opacity: 0.25;
			}
			&::-webkit-scrollbar-thumb {
				border-radius: 0;
				background-color: $-purdue-black;
				height: 5px;
			}
			.cover-card-slider__item {
				margin-right: 25px;
				position: relative;
				width: 660px;
				flex-direction: column;
				a {
					pointer-events: none;
				}
				.cover-card-slider__item__content {
					height: 395px;
					width: 660px;
					box-sizing: border-box;
					h4,
					.cover-card-slider__item__title {
						margin: 0 0 16px;
					}
					.cover-card-slider__item__excerpt {
						margin-top: 0;
					}
					a.button {
						margin: 0 auto;
						align-self: flex-end;
					}
				}
			}
		}
	}
}
