.rkv-block-cover-slider[class] {
	padding: 0;
	height: calc(100vh - #{$rkv-app-header-height});
	body.header-convergent & {
		height: calc(85vh);
	}
	@include mq($until: md) {
		body.header-convergent & {
			height: calc(88.3vh);
		}
	}
	@include mq($until: sm) {
		body.header-convergent & {
			height: calc(84vh);
		}
	}

	overflow: hidden;
	position: relative;

	.rkv-block-cover-slider-slides {
		position: absolute;
		z-index: 2;
		width: 440px;
		right: max(52px, calc(52px + (100vw - #{$rkv-max-width-container}) / 2));
		bottom: 52px;

		@include mq($until: md) {
			width: calc(100% - 2 * #{$rkv-gutter});
			left: $rkv-gutter;
			bottom: $rkv-gutter;
			right: $rkv-gutter;
		}
		background: rgba(255, 255, 255, 0.8);
		.cover-slider__item {
			width: 100%;
			height: 100%;
			padding: $rkv-gutter-double;
			@include mq($until: sm) {
				padding: $rkv-gutter;
			}
			background-image: none !important;
			.rkv-entry-theme {
				display: flex;
				justify-content: flex-start;
				margin-bottom: $rkv-gutter;
				> a {
					background: $-purdue-yellow;
					text-align: center;
					display: block;
					font-family: $rkv-font-family-headings;
					font-size: $rkv-font-size-medium;
					line-height: 1;
					letter-spacing: 0.35px;
					color: $-purdue-black;
					padding: 6px 15px;
					font-weight: bold;
					text-transform: uppercase;
					text-decoration: none;
				}
			}
			h4,
			.cover-slider__item__title {
				font-size: 25px;
				@include mq($until: sm) {
					font-size: 18px;
				}
				line-height: 1.2;
				font-weight: 600;
				font-family: $rkv-button-font-family;
				color: $-rkv-color-black;
				margin-bottom: $rkv-gutter-double;
				a {
					text-decoration: none;
					color: inherit;
				}
			}
			a.button.read-more {
				background: $-purdue-yellow;
				text-align: center;
				font-size: 1rem;
				font-family: $acumin-pro;
				font-weight: 400;
				padding: 12px 20px;
				line-height: 1.5;
				vertical-align: middle;
				color: $-purdue-black;
				border: 2px solid black;
				text-decoration: none;
				height: auto;
				border-radius: 0;
				&:hover {
					background: $-purdue-black;
					color: $-purdue-yellow;
				}
			}
		}

		.rkv-block-cover-slider-slides-navigation-and-controls {
			display: flex;
			justify-content: space-between;
			align-items: center;
			padding: $rkv-gutter-double;
			@include mq($until: sm) {
				padding: $rkv-gutter;
			}
			padding-top: 0;
			.rkv-block-cover-slider-slides-navigation {
				display: flex;
				@supports (aspect-ratio: 1 / 1) {
					gap: 8px;
				}
				button {
					width: 12px;
					height: 12px;
					background: transparent;
					border: 1px #555960 solid;
					border-radius: 50%;
					&.active,
					&.tns-nav-active {
						background: $-rkv-color-black;
						border: 1px $-rkv-color-black solid;
					}
					margin-right: 8px;
					&:last-child {
						margin-right: 0px;
					}
					@supports (aspect-ratio: 1 / 1) {
						margin: 0;
					}
				}
			}
			.rkv-block-cover-slider-slides-controls {
				display: flex;
				@supports (aspect-ratio: 1 / 1) {
					gap: 32px;
				}
				&.outline-adjust {
					outline: none;
					* {
						outline: none;
					}
				}
				button {
					width: 22px;
					height: 25px;
					background: transparent;
					border: none;
					svg * {
						fill: #555960;
					}
					&:active,
					&:hover {
						svg * {
							fill: $-rkv-color-black;
						}
					}
					&:first-child {
						margin-right: 16px;
					}
					&:last-child {
						margin-left: 16px;
					}
					@supports (aspect-ratio: 1 / 1) {
						margin: 0;
						&:first-child,
						&:last-child {
							margin: 0;
						}
					}
				}
			}
		}
	}

	.rkv-block-cover-slider-background-slides {
		width: 100vw;
		height: 100%;
		position: absolute;
		top: 0;
		left: 0;
		z-index: 1;
		list-style: none;
		pointer-events: none;
		.cover-slider__item {
			width: 100%;
			height: 100%;
			background-position: center center;
			background-size: cover;
			background-repeat: no-repeat;
			video {
				object-fit: cover;
				width: 100%;
				height: auto;
				display: block;
				min-height: 100%;
			}
		}
	}

	.editor-styles-wrapper .is-root-container[class] & {
		padding: 0;
		height: auto;
		display: grid;
		grid-template-columns: repeat(2, 1fr);
		gap: $rkv-gutter;
		> .rkv-block-cover-slider-slides-container,
		> .rkv-block-cover-slider-background-slides {
			padding: 0;
			display: grid;
			grid-template-rows: subgrid;
			gap: $rkv-gutter;
		}
		.cover-slider__item a {
			pointer-events: none;
		}
		.rkv-block-cover-slider-slides {
			position: relative;
			.rkv-block-cover-slider-slides-container {
			}
			.rkv-block-cover-slider-slides-navigation-and-controls {
				display: none;
			}
		}
		.rkv-block-cover-slider-background-slides {
			width: auto;
			height: auto;
			position: relative;
			list-style: none;
		}
	}
}
