!function(){var e={260:function(){wp.domReady(()=>{wp.blocks.registerBlockStyle("core/heading",{name:"has-font-acumin-pro-condensed",label:wp.i18n.__("Font - Acumin Pro Condensed","rkv-theme"),isDefault:!1}),wp.blocks.registerBlockStyle("core/heading",{name:"has-font-united-sans-condensed",label:wp.i18n.__("Font - United Sans Condensed","rkv-theme"),isDefault:!1}),wp.blocks.registerBlockStyle("core/group",{name:"is-narrow",label:wp.i18n.__("Narrow Centered","rkv-theme"),isDefault:!1}),wp.blocks.registerBlockStyle("core/button",{name:"view-all",label:wp.i18n.__("View All >","rkv-theme"),isDefault:!1}),wp.blocks.unregisterBlockStyle("core/image","rounded"),wp.blocks.registerBlockStyle("core/image",{name:"full-width-parallax",label:wp.i18n.__("Full Width Parallax with Caption","rkv-theme"),isDefault:!1}),wp.blocks.registerBlockVariation("core/gallery",{name:"purdue-carousel",title:wp.i18n.__("Slider","rkv-theme"),description:wp.i18n.__("A basic carousel slider based on the Gallery block.","rkv-theme"),icon:"slides",attributes:{align:"full",className:"purdue_carousel_default",title:"Slider"},scope:["block","inserter","transform"]}),wp.blocks.unregisterBlockStyle("core/quote","default"),wp.blocks.unregisterBlockStyle("core/quote","large"),wp.blocks.registerBlockStyle("core/quote",{name:"black-background",label:wp.i18n.__("Black Background","rkv-theme"),isDefault:!0}),wp.blocks.registerBlockStyle("core/quote",{name:"white-background",label:wp.i18n.__("White Background","rkv-theme"),isDefault:!0})})}},r={};function t(l){var o=r[l];if(void 0!==o)return o.exports;var n=r[l]={exports:{}};return e[l](n,n.exports,t),n.exports}t.n=function(e){var r=e&&e.__esModule?function(){return e.default}:function(){return e};return t.d(r,{a:r}),r},t.d=function(e,r){for(var l in r)t.o(r,l)&&!t.o(e,l)&&Object.defineProperty(e,l,{enumerable:!0,get:r[l]})},t.o=function(e,r){return Object.prototype.hasOwnProperty.call(e,r)},function(){"use strict";t(260)}()}();