@import '../../style/front-end/variables.scss';

.storytelling-content-block {
     text-align: center;
     font-size: 1.25rem;
    p:nth-of-type(odd) {
        font-family: $united-sans;
        font-weight: 700;
        font-size: 1.5rem;
    }

    &.has-background-black {
        p:nth-of-type(odd) {
            color: $boiler-gold;
        }

        p:nth-of-type(even) {
            color: #ffffff;
        }

    }

}

.storytelling-content-block::before {
  pointer-events: none;
}