.post-template-single-photo-essay{
    .main-content{
        .section:first-of-type{
            padding-top: 0px;
        }
    }
    .post-content{
        h1, .post-content__subheading{
            color: #000;
            text-align: center;
        }
        h1{
            margin-top: 3rem;
            font-size: 3rem;
            line-height: 56px;
        }
        .post-content__subheading{
            font-size: 1rem;
            line-height: 1.75;
        }
        .post-content__thumbnail{
            padding-top: 75% !important;
            margin-bottom: 0;
            &.image-position-center{
                img{
                    object-fit: cover;
                    object-position: center center;
                }
            }
            &.image-position-top{
                img{
                    object-fit: cover;
                    object-position: top center;
                }
            }
            &.image-position-bottom{
                img{
                    object-fit: cover;
                    object-position: bottom center;
                }
            }
            img{
                border-radius: 0 !important;
            }

            .post-content__thumbnail--caption{
                &::before{
                    content: "";
                    height: 150vh;
                }
            }
        }

        .photo-essay{
                position: relative;
                max-width: 1648px;
                margin-left: -824px;
                margin-right: -824px;
                padding-left: 16px;
                padding-right: 16px;
                left: 50%;
                right: 50%;

                @media screen and (max-width: 1648px){
                    width: 100vw;
                    max-width: calc(100vw - 16px);
                    margin-left: calc(-50vw + 50% + 8px);
                    margin-right: calc(-50vw + 50% + 8px);
                    left: 0;
                    right: 0;
                    
                }

                @media screen and (max-width: 1023px){
                 padding: 0 6px;
                }
        }
    }
}