.purdue-storytelling-side-by-side{
    flex-wrap: nowrap;
    display: flex;
    margin-bottom: 3rem !important;

    .wp-block-image {
        height: 100%;

        img {
            height: 100% !important;
            object-fit: cover;
        }
    }

    .column{
        display: flex;
    }
}