.rkv-slider-box-title-button[class] {
	padding: 0;
	position: relative;

	.slider__item {
		height: 318px !important;
		width: 318px !important;
		box-shadow: 0px 3px 6px #00000029;
		border: 1px solid $-purdue-steel;
		background-color: $-purdue-black;
		display: inline-grid !important;
		grid-template: 'container';
		place-items: center;
		place-content: center;
		overflow: hidden;
		position: relative;
		> * {
			grid-area: container;
		}
		.slider__item__background-image {
			z-index: 1;
			transition: all 0.6s;
			min-height: 318px;
			height: 318px;
			max-width: initial;
			object-fit: cover;
		}
		&:hover .slider__item__background-image {
			transform: scale(1.1);
			opacity: 0.35;
		}
		.slider__item__content {
			text-align: center;
			background: transparent;
			height: 318px !important;
			width: 318px !important;
			display: flex;
			flex-wrap: wrap;
			justify-content: center;
			align-items: center;
			align-content: center;
			overflow: hidden;
			position: relative;
			z-index: 2;
			background-image: linear-gradient(rgba(0, 0, 0, 0) 0%, rgba(0, 0, 0, 1) 100%);
			padding: $rkv-gutter-double;
			box-sizing: border-box;
			h4,
			.slider__item__title {
				font-size: 25px;
				line-height: 1.2;
				font-weight: 400;
				font-family: $rkv-button-font-family;
				font-weight: 600;
				color: $-rkv-color-white;
				margin: 0 auto $rkv-gutter-double;
				text-align: center;
				width: 100%;
				flex-grow: 1;
				position: relative;
				bottom: -1 * $rkv-gutter-triple;
				transition: all 0.6s;

				a {
					text-decoration: none;
					color: inherit;
				}
			}

			a.button {
				background: $-purdue-yellow-brighter;
				text-align: center;
				font-size: $rkv-font-size-default;
				font-family: $acumin-pro-semicondensed;
				font-weight: 600;
				padding: 15px 35px;
				line-height: 0.7;
				vertical-align: middle;
				color: $-purdue-black;
				border: 1px solid $-purdue-gray;
				text-decoration: none;
				height: auto;
				border-radius: $-rkv-border-radius-default;
				flex-grow: 0;
				opacity: 0;
				transition: all 0.6s;
				&:hover {
					background: $-purdue-black;
					color: $-purdue-white;
				}
			}
			&:hover {
				h4,
				.slider__item__title {
					bottom: 0;
				}
				a.button {
					opacity: 1;
				}
			}
		}
	}

	@include purdue_carousel_tinyslider_default(100%);
}
// Editor

.editor-styles-wrapper .is-root-container[class] .purdue_carousel_default {
	width: 100%;
	max-width: none;
	.rkv-slider-box-title-button[class] {
		width: 100%;

		.rkv-slider-box-title-button-slides {
			display: flex;
			flex-wrap: nowrap;
			overflow-x: scroll;
			overflow-y: hidden;
			height: 395px;
			flex-direction: row;
			padding-bottom: 16px;
			margin-bottom: 16px;
			padding-left: 0;
			min-width: 100%;
			width: 100%;
			&::-webkit-scrollbar {
				height: 2px;
			}
			&::-webkit-scrollbar-track {
				background-color: $-purdue-black;
				border-radius: 0;
				opacity: 0.25;
			}
			&::-webkit-scrollbar-thumb {
				border-radius: 0;
				background-color: $-purdue-black;
				height: 5px;
			}
			.slider__item {
				margin-right: 25px;
				position: relative;
				width: 318px !important;
				flex-direction: column;
				flex-shrink: 0;
				a {
					pointer-events: none;
				}
				.slider__item__content {
					height: 318px;
					width: 318px;
					box-sizing: border-box;
					h4,
					.slider__item__title {
						margin: 0 0 16px;
					}

					a.button {
						margin: 0 auto;
						align-self: flex-end;
					}
				}
			}
		}
	}
}
