!function(){let e=document.querySelector(".purdue-at-a-glance__expand"),t=document.querySelector(".purdue-at-a-glance");document.querySelector(".extra-text"),e&&e.addEventListener("click",a=>{a.preventDefault(),t.classList.contains("is-open")?(t.classList.remove("is-open"),e.setAttribute("aria-expanded",!1),e.textContent="Expand"):(t.classList.add("is-open"),e.setAttribute("aria-expanded",!0),e.textContent="Collapse")})}();