.post-content__thumbnail.youtube-lite-container.purdue-home-cta-card{
	box-shadow:none;
	overflow:visible;
	margin-bottom:3rem;
	.cta-icon.cta-icon--play{
		@include tablet{
			width:5rem;
			height:5rem;
		}
	}
	.cta-link{
		@include tablet{
			font-size:1.875rem;
		}
	}
}
