!function(){"use strict";var e,t={893:function(){var e=window.React,t=window.wp.blocks,a=window.wp.blockEditor,r=window.wp.i18n,n=window.wp.components,l=JSON.parse('{"UU":"purdue/storytelling-featured-content"}'),o=window.wp.primitives;(0,t.registerBlockType)(l.UU,{icon:()=>(0,e.createElement)(o.SVG,{id:"Layer_1","data-name":"Layer 1",xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 100 100"},(0,e.createElement)("defs",null),(0,e.createElement)("g",{id:"clone",className:"cls-1"},(0,e.createElement)("g",{className:"cls-1"},(0,e.createElement)(o.Path,{className:"cls-2",d:"M100,9.38V71.87a9.38,9.38,0,0,1-9.37,9.38H81.25v9.37A9.38,9.38,0,0,1,71.87,100H9.37A9.38,9.38,0,0,1,0,90.62V28.13a9.38,9.38,0,0,1,9.37-9.38h9.38V9.38A9.38,9.38,0,0,1,28.12,0H90.63A9.38,9.38,0,0,1,100,9.38ZM71.87,89.45v-8.2H28.12a9.38,9.38,0,0,1-9.37-9.38V28.13h-8.2A1.17,1.17,0,0,0,9.37,29.3V89.45a1.17,1.17,0,0,0,1.18,1.17H70.7A1.17,1.17,0,0,0,71.87,89.45ZM90.63,70.7V10.55a1.17,1.17,0,0,0-1.18-1.17H29.3a1.17,1.17,0,0,0-1.18,1.17V70.7a1.17,1.17,0,0,0,1.18,1.17H89.45A1.17,1.17,0,0,0,90.63,70.7Z",transform:"translate(0 0)"})))),edit:t=>{const{id:l,featuredImageID:o,featuredImageURL:c,featuredImageAlt:i}=t.attributes,{setAttributes:s}=t,u=(0,a.useBlockProps)({className:"storytelling-featured-block section"}),d=t.clientId&&wp.data.select("core/block-editor").getBlock(t.clientId).innerBlocks;return[(0,e.createElement)("div",{...u,className:"wp-block-purdue-storytelling-featured storytelling-featured",key:"1"},(0,e.createElement)("div",{className:"container"},(0,e.createElement)("div",{className:"section"},(0,e.createElement)(a.MediaUploadCheck,null,(0,e.createElement)(a.MediaUpload,{onSelect:e=>{s({featuredImageID:e.id,featuredImageURL:e.url,featuredImageAlt:e.alt})},allowedTypes:["image"],value:o,render:({open:t})=>(0,e.createElement)(e.Fragment,null,c?(0,e.createElement)("div",{className:"block-image-wrapper"},(0,e.createElement)("img",{src:c,alt:i}),(0,e.createElement)("div",{className:"block-image-controls"},(0,e.createElement)(n.Button,{onClick:t,variant:"secondary"},(0,r.__)("Replace","text-domain")),(0,e.createElement)(n.Button,{isDestructive:!0,onClick:()=>s({featuredImageID:null,featuredImageURL:"",featuredImageAlt:""})},(0,r.__)("Remove","text-domain")))):(0,e.createElement)(a.MediaPlaceholder,{onSelect:e=>{s({featuredImageID:e.id,featuredImageURL:e.url,featuredImageAlt:e.alt})},allowedTypes:["image"],multiple:!1}))})),(0,e.createElement)("div",{className:"columns featured-content-wrapper is-mobile"},(0,e.createElement)("div",{class:"column is-6 is-offset-3"},(0,e.createElement)(a.InnerBlocks,{templateLock:!1,allowedBlocks:["purdue/storytelling-content-block","purdue/storytelling-qa-block"],renderAppender:d?void 0:()=>(0,e.createElement)(a.InnerBlocks.DefaultBlockAppender,null)}))))))]},save:()=>(0,e.createElement)(a.InnerBlocks.Content,null)})}},a={};function r(e){var n=a[e];if(void 0!==n)return n.exports;var l=a[e]={exports:{}};return t[e](l,l.exports,r),l.exports}r.m=t,e=[],r.O=function(t,a,n,l){if(!a){var o=1/0;for(u=0;u<e.length;u++){a=e[u][0],n=e[u][1],l=e[u][2];for(var c=!0,i=0;i<a.length;i++)(!1&l||o>=l)&&Object.keys(r.O).every(function(e){return r.O[e](a[i])})?a.splice(i--,1):(c=!1,l<o&&(o=l));if(c){e.splice(u--,1);var s=n();void 0!==s&&(t=s)}}return t}l=l||0;for(var u=e.length;u>0&&e[u-1][2]>l;u--)e[u]=e[u-1];e[u]=[a,n,l]},r.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},function(){var e={728:0,256:0};r.O.j=function(t){return 0===e[t]};var t=function(t,a){var n,l,o=a[0],c=a[1],i=a[2],s=0;if(o.some(function(t){return 0!==e[t]})){for(n in c)r.o(c,n)&&(r.m[n]=c[n]);if(i)var u=i(r)}for(t&&t(a);s<o.length;s++)l=o[s],r.o(e,l)&&e[l]&&e[l][0](),e[l]=0;return r.O(u)},a=self.webpackChunkpurdue_home_theme_child=self.webpackChunkpurdue_home_theme_child||[];a.forEach(t.bind(null,0)),a.push=t.bind(null,a.push.bind(a))}();var n=r.O(void 0,[256],function(){return r(893)});n=r.O(n)}();