.has-white-color{color:#fff !important}.has-black-color{color:#000 !important}.has-aged-gold-color{color:#8e6f3e !important}.has-boiler-gold-color{color:#cfb991 !important}.has-rush-gold-color{color:#daaa00 !important}.has-field-gold-color{color:#ddb945 !important}.has-dust-gold-color{color:#ebd99f !important}.has-steel-gray-color{color:#555960 !important}.has-cool-gray-color{color:#6f727b !important}.has-steam-gray-color{color:#c4bfc0 !important}.has-railway-gray-color{color:#9d9795 !important}.has-opaque-color{color:rgba(0,0,0,.65) !important}.has-transparent-color{color:rgba(0,0,0,0) !important}.has-white-background-color{background-color:#fff !important}.has-black-background-color{background-color:#000 !important}.has-aged-gold-background-color{background-color:#8e6f3e !important}.has-boiler-gold-background-color{background-color:#cfb991 !important}.has-rush-gold-background-color{background-color:#daaa00 !important}.has-field-gold-background-color{background-color:#ddb945 !important}.has-dust-gold-background-color{background-color:#ebd99f !important}.has-steel-gray-background-color{background-color:#555960 !important}.has-cool-gray-background-color{background-color:#6f727b !important}.has-steam-gray-background-color{background-color:#c4bfc0 !important}.has-railway-gray-background-color{background-color:#9d9795 !important}.has-opaque-background-color{background-color:rgba(0,0,0,.65) !important}.has-transparent-background-color{background-color:rgba(0,0,0,0) !important}.has-background-black-ter{background-color:#555960 !important}.main-content{display:block}.home .content{margin-bottom:0 !important}.main-content>.content:not(:last-child){margin-bottom:0 !important}.content p{max-width:100%}hr.wp-block-separator{height:1px !important}@media screen and (-ms-high-contrast: active),(-ms-high-contrast: none){.columns.is-multiline{flex-wrap:none}.column{flex-basis:auto}}.united-sans-font{font-family:"United Sans",Impact,"Arial Black","sans serif" !important}strong{color:inherit !important}.storytelling-featured{position:relative}.storytelling-featured::before{content:"";display:inline-block;background-image:url(../../images/Student-storytelling-texture-background.0e22f92a.png);background-size:cover;background-repeat:no-repeat;background-position:center;position:absolute;top:0;max-height:75%;width:90%;height:100%;-ms-grid-row-align:center;align-self:center;bottom:0;border-radius:4px;left:0;right:0;margin:0 auto}.storytelling-featured .featured-texture{display:none;position:absolute;width:100%;padding:2rem 0rem;left:0;right:0;bottom:0;max-width:80%;margin:0 auto}.storytelling-featured .featured-texture img{height:100%;object-fit:cover;min-height:350px;border-radius:4px}.storytelling-featured .featured-image-wrapper{z-index:1}.storytelling-featured .featured-image-wrapper img{border-radius:4px}.storytelling-featured .featured-content-wrapper{z-index:2;position:relative;margin-top:3rem}.storytelling-featured .block-image-wrapper{z-index:10;position:relative;background:#fff;padding-bottom:2rem;width:100%}.storytelling-featured .block-image-wrapper img{object-fit:cover;width:100%}.storytelling-featured .block-image-controls{padding:1rem}.storytelling-featured .block-list-appender.wp-block{background-color:#fff;margin-top:1rem}
