.tns-item .archive-card {
	height: 400px !important;
	.archive-card__content {
		&-title {
			font-size: 1.125rem !important;
			max-height: 96px;
			-webkit-line-clamp: 4;
			-webkit-box-orient: vertical;
			display: -webkit-box;
			overflow: hidden;
			text-overflow: ellipsis;
		}
		&-description {
			display: none !important;
		}
	}
}
@mixin archive-card(
	$card-width: $rkv-gutter * 20,
	$card-height: $rkv-gutter * 24.5,
	$card-art-height-ratio: 0.5
) {
	.archive-card {
		box-shadow: 0px 3px 6px rgba($-purdue-black, 0.29);
		background-color: $-purdue-white;
		background-position: top;
		background-size: auto 50%;
		background-repeat: no-repeat;
		width: $card-width;
		position: relative;
		overflow: hidden;
		transition: all 0.3s;
		color: $-purdue-black;
		text-decoration: none;
		display: flex;
		flex-direction: column;
		height: 100%;
		a {
			text-decoration: none;
			color: inherit;
		}
		&:hover {
			.archive-card__background {
				transform: scale(1.1);
				> * {
					opacity: 0.8;
				}
			}
			.archive-card__content .archive-card__content-meta {
				button {
					background: black;
					color: $-purdue-yellow;
				}
			}
		}

		.archive-card__background {
			position: relative;
			padding-top: 56.25%;
			height: auto;
			top: 0;
			left: 0;
			width: 100%;
			z-index: 1;
			transition: all 0.3s;
			background: $-purdue-black;
			> * {
				object-fit: cover;
				position: absolute;
				width: 100%;
				height: 100%;
				top: 0;
				left: 0;
				min-height: 0;
				object-position: top;
			}
			> video {
				transform: scale(1.1);
			}
		}

		.archive-card__content {
			padding: 1.25rem;
			position: relative;
			z-index: 2;
			display: flex;
			flex-wrap: wrap;
			align-content: space-between;
			background-color: white;
			width: 100%;
			height: 100%;
			> * {
				flex-basis: 100%;
				transition: all 0.3s;
			}

			.archive-card__content-title {
				text-align: left;
				font-family: $rkv-button-font-family;
				font-size: 1.5rem;
				line-height: 1.3333333333;
				font-weight: 700;
				margin-bottom: $rkv-gutter;
				color: $-purdue-black;
			}
			.archive-card__content-description {
				text-align: left;
				font-family: $acumin-pro;
				font-size: $rkv-font-size-default;
				line-height: 1.3333333333;
				letter-spacing: 0px;
				color: black;
				> p {
					-webkit-line-clamp: 2;
					-webkit-box-orient: vertical;
					display: -webkit-box;
					overflow: hidden;
					text-overflow: ellipsis;
				}
			}
			.archive-card__content-type {
				color: black;
				margin-bottom: 0.5rem;
				svg {
					width: 14px;
					height: auto;
				}
				> span {
					font-size: 14px;
					text-transform: uppercase;
					font-family: $acumin-pro;
					font-weight: 700;
					margin-left: 0.8rem;
				}
			}
			.archive-card__content-meta {
				button {
					padding: 0.75rem 1.25rem;
					border: 2px solid black;
					background: $-purdue-yellow;
					font-size: 1rem;
					color: black;
					pointer-events: none;
				}
			}
		}
	}
}
