// ========================
// Media query breakpoints.
// ========================

/*
	Name your breakpoints in a way that creates a
	ubiquitous language across all team members.

	It will improve communication between:

	- developers
	- designers
	- stakeholders
	- testers
*/

// prettier-ignore
$-rkv-custom-breakpoints: (
	// Leave this empty!
) !default;

// prettier-ignore
$-rkv-default-breakpoints: (
	alignwide: $rkv-max-width-container,
	rkv-app-header: 800px,
	rkv-app-footer: 800px,
	rkv-block-callout: 800px,
	rkv-block-media: 600px,
) !default;

// prettier-ignore
$mq-breakpoints: rkv-map-merge(
	$rkv-grid-breakpoints,
	$-rkv-default-breakpoints,
	$-rkv-custom-breakpoints,
) !default;

// ================
// Helper function.
// ================

@function rkv-breakpoint($key) {
	@if map-has-key($mq-breakpoints, $key) {
		@return map-get($mq-breakpoints, $key);
	}

	@error "Unknown `rkv-breakpoint(#{$key})`";
}

// =============
// Other config.
// =============

$mq-responsive: true !default;
$mq-static-breakpoint: md !default;

/*
	Uncomment, to show breakpoints
	at the top-right of the screen.
*/
// $mq-show-breakpoints: (xs, sm, md, lg) !default;

/*
	Read more:

	https://github.com/sass-mq/sass-mq
*/
@import '../_vendor/sass-mq';
