!function(){"use strict";var e,t={310:function(){var e=window.React,t=window.wp.blocks,n=window.wp.blockEditor,r=(window.wp.i18n,window.wp.components);const o=[["core/paragraph",{placeholder:"Add content"}]];var a=JSON.parse('{"UU":"purdue/at-a-glance"}');(0,t.registerBlockType)(a.UU,{edit:t=>{const{setAttributes:a}=t,{id:l,text:c}=t.attributes,i=(0,n.useBlockProps)();return a({id:t.clientId}),[(0,e.createElement)(n.InspectorControls,{key:"1"},(0,e.createElement)(r.PanelBody,null,(0,e.createElement)(r.PanelRow,null,(0,e.createElement)(r.TextControl,{label:"HTML Anchor",help:"Enter a word without spaces to make a unique web address just for this block, called an “anchor.” It must be unique from any other anchors on the page. Then, you’ll be able to link directly to this section of your page.",value:l,onChange:e=>a({id:e})})))),(0,e.createElement)("div",{...i,key:"2"},(0,e.createElement)("div",{className:"purdue-at-a-glance"},(0,e.createElement)("div",{className:"section"},(0,e.createElement)("p",null,(0,e.createElement)("strong",null,"At a Glance:")),(0,e.createElement)(n.InnerBlocks,{template:o,templateLock:!1}))))]},save:()=>(0,e.createElement)(n.InnerBlocks.Content,null)})}},n={};function r(e){var o=n[e];if(void 0!==o)return o.exports;var a=n[e]={exports:{}};return t[e](a,a.exports,r),a.exports}r.m=t,e=[],r.O=function(t,n,o,a){if(!n){var l=1/0;for(s=0;s<e.length;s++){n=e[s][0],o=e[s][1],a=e[s][2];for(var c=!0,i=0;i<n.length;i++)(!1&a||l>=a)&&Object.keys(r.O).every(function(e){return r.O[e](n[i])})?n.splice(i--,1):(c=!1,a<l&&(l=a));if(c){e.splice(s--,1);var u=o();void 0!==u&&(t=u)}}return t}a=a||0;for(var s=e.length;s>0&&e[s-1][2]>a;s--)e[s]=e[s-1];e[s]=[n,o,a]},r.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},function(){var e={691:0,707:0};r.O.j=function(t){return 0===e[t]};var t=function(t,n){var o,a,l=n[0],c=n[1],i=n[2],u=0;if(l.some(function(t){return 0!==e[t]})){for(o in c)r.o(c,o)&&(r.m[o]=c[o]);if(i)var s=i(r)}for(t&&t(n);u<l.length;u++)a=l[u],r.o(e,a)&&e[a]&&e[a][0](),e[a]=0;return r.O(s)},n=self.webpackChunkpurdue_home_theme_child=self.webpackChunkpurdue_home_theme_child||[];n.forEach(t.bind(null,0)),n.push=t.bind(null,n.push.bind(n))}();var o=r.O(void 0,[707],function(){return r(310)});o=r.O(o)}();