.photo-essay{display:flex;flex-wrap:wrap}.photo-essay .is-12-desktop{text-align:center}.photo-essay .is-12-desktop figure>figcaption,.photo-essay .is-12-desktop .wp-block-image>figcaption{text-align:center;margin:1.5rem auto 0 auto !important;width:auto;max-width:-webkit-fit-content;max-width:fit-content}@media screen and (max-width: 1023px){.photo-essay .is-4-desktop:last-of-type{width:100%}}.photo-essay .is-fullheight .wp-block-image,.photo-essay .is-fullheight img{height:100% !important}.photo-essay .is-left .wp-block-image:not(:last-child),.photo-essay .is-right .wp-block-image:not(:last-child){margin-bottom:1.5rem}@media screen and (max-width: 767px){.photo-essay .is-left .wp-block-image:not(:last-child),.photo-essay .is-right .wp-block-image:not(:last-child){margin-bottom:.75rem}}.photo-essay .is-left .wp-block-image:not(:first-child),.photo-essay .is-right .wp-block-image:not(:first-child){margin-top:1.5rem}@media screen and (max-width: 767px){.photo-essay .is-left .wp-block-image:not(:first-child),.photo-essay .is-right .wp-block-image:not(:first-child){margin-top:.75rem}}@media screen and (max-width: 767px){.photo-essay .column{padding:12px 6px 0 !important}}
