!function(){"use strict";var e,t={298:function(){var e=window.React,t=window.wp.blocks,a=window.wp.blockEditor,l=window.wp.i18n,n=window.wp.components,c=JSON.parse('{"UU":"purdue/storytelling-content-block"}'),r=window.wp.primitives;(0,t.registerBlockType)(c.UU,{icon:()=>(0,e.createElement)(r.SVG,{id:"Layer_1","data-name":"Layer 1",xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 100 100"},(0,e.createElement)("defs",null),(0,e.createElement)("g",{id:"clone",className:"cls-1"},(0,e.createElement)("g",{className:"cls-1"},(0,e.createElement)(r.Path,{className:"cls-2",d:"M100,9.38V71.87a9.38,9.38,0,0,1-9.37,9.38H81.25v9.37A9.38,9.38,0,0,1,71.87,100H9.37A9.38,9.38,0,0,1,0,90.62V28.13a9.38,9.38,0,0,1,9.37-9.38h9.38V9.38A9.38,9.38,0,0,1,28.12,0H90.63A9.38,9.38,0,0,1,100,9.38ZM71.87,89.45v-8.2H28.12a9.38,9.38,0,0,1-9.37-9.38V28.13h-8.2A1.17,1.17,0,0,0,9.37,29.3V89.45a1.17,1.17,0,0,0,1.18,1.17H70.7A1.17,1.17,0,0,0,71.87,89.45ZM90.63,70.7V10.55a1.17,1.17,0,0,0-1.18-1.17H29.3a1.17,1.17,0,0,0-1.18,1.17V70.7a1.17,1.17,0,0,0,1.18,1.17H89.45A1.17,1.17,0,0,0,90.63,70.7Z",transform:"translate(0 0)"})))),edit:t=>{const{id:c,factTitle:r,factText:o,factTitle2:i,factText2:s,factTitle3:d,factText3:u,background:h}=t.attributes,{setAttributes:m,isSelected:f}=t,p=(0,a.useBlockProps)({className:`storytelling-content-block has-background-${h}`});return(0,a.useInnerBlocksProps)({className:"storytelling-content-block__inner"},{templateLock:!1}),[(0,e.createElement)(a.InspectorControls,{key:"1"},(0,e.createElement)(n.PanelBody,{title:(0,l.__)("Background Settings","purdue-home-theme-child-contenthub")},(0,e.createElement)(n.PanelRow,null,(0,e.createElement)(n.SelectControl,{label:"Choose the background of this slide.",value:h,options:[{label:"White",value:"white"},{label:"Black",value:"black"},{label:"Gray",value:"gray"}],onChange:e=>m({background:e})})))),(0,e.createElement)("div",{...p,key:"2"},(0,e.createElement)("div",{className:"storytelling-content-block__decorative-bar"}),(0,e.createElement)(a.RichText,{tagName:"p",value:r,placeholder:"Add fact title…",onChange:e=>m({factTitle:e}),allowedFormats:["core/bold","core/italic"]}),(0,e.createElement)(a.RichText,{tagName:"p",value:o,placeholder:"Add fact text…",onChange:e=>m({factText:e})}),(0,e.createElement)(a.RichText,{tagName:"p",value:i,placeholder:"Add fact title 2…",onChange:e=>m({factTitle2:e}),allowedFormats:["core/bold","core/italic"]}),(0,e.createElement)(a.RichText,{tagName:"p",value:s,placeholder:"Add fact text 2…",onChange:e=>m({factText2:e})}),(0,e.createElement)(a.RichText,{tagName:"p",value:d,placeholder:"Add fact title 3…",onChange:e=>m({factTitle3:e}),allowedFormats:["core/bold","core/italic"]}),(0,e.createElement)(a.RichText,{tagName:"p",value:u,placeholder:"Add fact text 3…",onChange:e=>m({factText3:e})}))]},save:()=>(0,e.createElement)(a.InnerBlocks.Content,null)})}},a={};function l(e){var n=a[e];if(void 0!==n)return n.exports;var c=a[e]={exports:{}};return t[e](c,c.exports,l),c.exports}l.m=t,e=[],l.O=function(t,a,n,c){if(!a){var r=1/0;for(d=0;d<e.length;d++){a=e[d][0],n=e[d][1],c=e[d][2];for(var o=!0,i=0;i<a.length;i++)(!1&c||r>=c)&&Object.keys(l.O).every(function(e){return l.O[e](a[i])})?a.splice(i--,1):(o=!1,c<r&&(r=c));if(o){e.splice(d--,1);var s=n();void 0!==s&&(t=s)}}return t}c=c||0;for(var d=e.length;d>0&&e[d-1][2]>c;d--)e[d]=e[d-1];e[d]=[a,n,c]},l.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},function(){var e={191:0,143:0};l.O.j=function(t){return 0===e[t]};var t=function(t,a){var n,c,r=a[0],o=a[1],i=a[2],s=0;if(r.some(function(t){return 0!==e[t]})){for(n in o)l.o(o,n)&&(l.m[n]=o[n]);if(i)var d=i(l)}for(t&&t(a);s<r.length;s++)c=r[s],l.o(e,c)&&e[c]&&e[c][0](),e[c]=0;return l.O(d)},a=self.webpackChunkpurdue_home_theme_child=self.webpackChunkpurdue_home_theme_child||[];a.forEach(t.bind(null,0)),a.push=t.bind(null,a.push.bind(a))}();var n=l.O(void 0,[143],function(){return l(298)});n=l.O(n)}();